@@ -1,4 +1,4 @@
-Midnight Commander (c) 1995-1997, Free Software Foundation
+Midnight Commander (c) 1995-2001, Free Software Foundation
 Porada: Za pomoc C-x t kopiuje si nazwy zaznaczoych plikw do wiersza polece.
 Porada: Za pomoc C-x p kopiuje si nazw biecej cieki do wiersza polece.
 Porada: Uzupenianie: M-Tab (lub Esc+Tab). Podwjne wcinicie wywouje list.
@@ -7,10 +7,9 @@ Porada: Cytowanie znaku mona uzyska naciskajc Contrl-q i odpowiedni znak.
 Porada: Zmczony poradami? Wycz je w menu Opcje|Ukad...
 Porada: Wybieranie katalogw: dodaj ukonik na kocu wzorca dopasowania.
 Porada: Jeli w twoim terminalu brak klawiszy funkcyjnych, uyj Esc+numer.
-Porada: Witryna Midnight Commandera jest pod adresem http://www.gnome.org/mc/
-Porada: Najnowsza wersja MC pod adresem ftp://ftp.gnome.org/pub/GNOME/sources/mc
-Porada: Opis bdw (w jzyku angielskim) wysyaj na mc-bugs@nuclecu.unam.mx
-Porada: Strona domowa Midnight Commandera pod adresem http://www.gnome.org/mc
+Porada: Witryna Midnight Commandera jest pod adresem http://www.ibiblio.org/mc/
+Porada: Strona domowa Midnight Commandera pod adresem http://www.ibiblio.org/mc/
+Porada: Opis bdw (w jzyku angielskim) wysyaj na mc-devel@gnome.org
 Porada: Za pomoc klawisza Tab zmienia si biecy panel.
 Porada: VFS: nacinij Enter na archiwum tar, aby obejrze jego zawarto.
 Porada: Na stron podrcznikow te warto zajrze.
@@ -23,7 +22,6 @@ Porada: Dostp do zwykej powoki przez C-o. Powrt do MC przez ponowne C-o.
 Porada: Ustawienie zmiennej CDPATH moe ci zaoszczdzi pisania.
 Porada: Jeli chcesz zobaczy pliki .*, zmie ustawienie w menu Konfiguracja...
 Porada: Jeli chcesz zobaczy pliki .*~, zmie ustawienie w menu Konfiguracja...
-Porada: Masz duo pamici? Ustaw limit pamici VFS archiwum tar na -1.
 Porada: Uzupenianie dziaa wszdzie. Po prostu nacinij M-Tab.
 Porada: Jeli masz powolny terminal, sprbuj uy opcji -s.
 Porada: Znajd plik: na znalezionych plikach wykonujemy operacje poprzez Filtruj.
