@@ -20,15 +20,15 @@
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
-#include "tty.h"
 #include <string.h>
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/param.h>
 #include <signal.h>
 #include <ctype.h>
+
 #include "global.h"
+#include "tty.h"
 #include "win.h"		/* Our window tools */
 #include "color.h"		/* Color definitions */
 #include "dlg.h"		/* The nice dialog manager */
@@ -45,18 +45,17 @@
 #include "main.h"		/* For the confirm_* variables */
 #include "tree.h"
 #include "layout.h"		/* for get_nth_panel_name proto */
-#include "fileopctx.h"
 #include "background.h"
-#include "x.h"
 
 #ifdef HAVE_CHARSET
 #include "charsets.h"
 #include "selcodepage.h"
 #endif
 
-#ifdef WITH_SMBFS
-#include "../vfs/vfs.h"		/* smb_authinfo */
-#endif /* WITH_SMBFS */
+#include "../vfs/vfs.h"		/* vfs_timeout */
+#ifdef USE_NETCODE
+#   include "../vfs/ftpfs.h"
+#endif
 
 static int DISPLAY_X = 45, DISPLAY_Y = 14;
 
@@ -66,21 +65,20 @@ static WInput *user;
 static WInput *status;
 static WCheck *check_status;
 static int current_mode;
-extern int ftpfs_always_use_proxy;
 
 static char **displays_status;
-static char* display_title = N_(" Listing mode ");
 
 /* Controls whether the array strings have been translated */
-static int i18n_displays_flag;
 static char *displays [LIST_TYPES] = {
     N_("&Full file list"),
     N_("&Brief file list"),
     N_("&Long file list"),
-    N_("&User defined:"),
-    N_("&Icon view"),
+    N_("&User defined:")
 };
 
+/* Index in displays[] for "user defined" */
+#define USER_TYPE 3
+
 static int user_hotkey = 'u';
 
 static int
@@ -88,14 +86,7 @@ display_callback (struct Dlg_head *h, int id, int Msg)
 {
     switch (Msg){
     case DLG_DRAW:
-	attrset (COLOR_NORMAL);
-	dlg_erase (h);
-	draw_box (h, 1, 2, h->lines - 2, h->cols - 4);
-
-	attrset (COLOR_HOT_NORMAL);
-	dlg_move (h, 1, (h->cols - strlen(display_title))/2);
-	addstr (display_title);
-	attrset (COLOR_NORMAL);
+	common_dialog_repaint (h);
 	break;
 
     case DLG_UNFOCUS:
@@ -138,79 +129,84 @@ display_callback (struct Dlg_head *h, int id, int Msg)
 }
 
 static void
-display_init (int radio_sel, char *init_text,
-	      int _check_status, char ** _status)
+display_init (int radio_sel, char *init_text, int _check_status,
+	      char **_status)
 {
-	char* user_mini_status = _("user &Mini status");
-	char* ok_button = _("&Ok");
-	char* cancel_button = _("&Cancel");
-	
-	static int button_start = 30;
-	
+    static char *display_title = N_("Listing mode");
+    static int i18n_displays_flag;
+    char *user_mini_status = _("user &Mini status");
+    char *ok_button = _("&OK");
+    char *cancel_button = _("&Cancel");
+
+    static int button_start = 30;
+
     displays_status = _status;
 
-    if (!i18n_displays_flag){
-		int i, l, maxlen = 0;
-		char* cp;
+    if (!i18n_displays_flag) {
+	int i, l, maxlen = 0;
+	char *cp;
 
- 		display_title = _(display_title);
-		for (i = 0; i < LIST_TYPES; i++)
-		{
-		    displays [i] = _(displays [i]);
-			if ((l = strlen(displays [i])) > maxlen)
-				maxlen = l;
-		}
+	display_title = _(display_title);
+	for (i = 0; i < LIST_TYPES; i++) {
+	    displays[i] = _(displays[i]);
+	    if ((l = strlen (displays[i])) > maxlen)
+		maxlen = l;
+	}
 
-		i = strlen (ok_button) + 5;
-		l = strlen (cancel_button) + 3;
-		l = max(i, l);
+	i = strlen (ok_button) + 5;
+	l = strlen (cancel_button) + 3;
+	l = max (i, l);
 
-		i = maxlen + l + 16;
-		if (i > DISPLAY_X)
-			DISPLAY_X = i;
+	i = maxlen + l + 16;
+	if (i > DISPLAY_X)
+	    DISPLAY_X = i;
 
-		i = strlen (user_mini_status) + 13;
-		if (i > DISPLAY_X)
-			DISPLAY_X = i;
-			
-		i = strlen (display_title) + 8;
-		if (i > DISPLAY_X)
-			DISPLAY_X = i;
+	i = strlen (user_mini_status) + 13;
+	if (i > DISPLAY_X)
+	    DISPLAY_X = i;
 
-		button_start = DISPLAY_X - l - 5;
-		
-		/* get hotkey of user-defined format string */
-		cp = strchr(displays[LIST_TYPES-1],'&');
-		if (cp != NULL && *++cp != '\0')
-			user_hotkey = tolower(*cp);
+	i = strlen (display_title) + 10;
+	if (i > DISPLAY_X)
+	    DISPLAY_X = i;
 
-        i18n_displays_flag = 1;
+	button_start = DISPLAY_X - l - 5;
+
+	/* get hotkey of user-defined format string */
+	cp = strchr (displays[USER_TYPE], '&');
+	if (cp != NULL && *++cp != '\0')
+	    user_hotkey = tolower (*cp);
+
+	i18n_displays_flag = 1;
     }
     dd = create_dlg (0, 0, DISPLAY_Y, DISPLAY_X, dialog_colors,
-		     display_callback, "[Listing Mode...]", "display",
-		     DLG_CENTER | DLG_GRID);
-
-    x_set_dialog_title (dd, _("Listing mode"));
-    add_widget (dd,
-        button_new (4, button_start, B_CANCEL, 
-			NORMAL_BUTTON, cancel_button, 0, 0, "cancel-button"));
+		     display_callback, "[Listing Mode...]", display_title,
+		     DLG_CENTER);
 
     add_widget (dd,
-		button_new (3, button_start, B_ENTER, 
-			DEFPUSH_BUTTON, ok_button, 0, 0, "ok-button"));
+		button_new (4, button_start, B_CANCEL, NORMAL_BUTTON,
+			    cancel_button, 0, 0, "cancel-button"));
 
-    status = input_new (10, 9, INPUT_COLOR, DISPLAY_X-14, _status [radio_sel], "mini-input");
+    add_widget (dd,
+		button_new (3, button_start, B_ENTER, DEFPUSH_BUTTON,
+			    ok_button, 0, 0, "ok-button"));
+
+    status =
+	input_new (10, 9, INPUT_COLOR, DISPLAY_X - 14, _status[radio_sel],
+		   "mini-input");
     add_widget (dd, status);
     input_set_point (status, 0);
 
-    check_status = check_new (9, 5, _check_status, user_mini_status, "mini-status");
+    check_status =
+	check_new (9, 5, _check_status, user_mini_status, "mini-status");
     add_widget (dd, check_status);
-    
-    user = input_new  (7, 9, INPUT_COLOR, DISPLAY_X-14, init_text, "user-fmt-input");
+
+    user =
+	input_new (7, 9, INPUT_COLOR, DISPLAY_X - 14, init_text,
+		   "user-fmt-input");
     add_widget (dd, user);
     input_set_point (user, 0);
 
-    my_radio = radio_new (3, 5, LIST_TYPES-1, displays, 1, "radio");
+    my_radio = radio_new (3, 5, LIST_TYPES, displays, 1, "radio");
     my_radio->sel = my_radio->pos = current_mode;
     add_widget (dd, my_radio);
 }
@@ -265,9 +261,9 @@ display_box (WPanel *panel, char **userp, char **minip, int *use_msformat, int n
     return result;
 }
 
-int SORT_X = 40, SORT_Y = 14;
+static int SORT_X = 40, SORT_Y = 14;
 
-char *sort_orders_names [SORT_TYPES];
+static char *sort_orders_names [SORT_TYPES];
 
 sortfn *
 sort_box (sortfn *sort_fn, int *reverse, int *case_sensitive)
@@ -276,7 +272,7 @@ sort_box (sortfn *sort_fn, int *reverse, int *case_sensitive)
     sortfn *result;
     WCheck *c, *case_sense;
 
-	char* ok_button = _("&Ok");
+	char* ok_button = _("&OK");
 	char* cancel_button = _("&Cancel");
 	char* reverse_label = _("&Reverse");
 	char* case_label = _("case sensi&tive");
@@ -329,10 +325,8 @@ sort_box (sortfn *sort_fn, int *reverse, int *case_sensitive)
 	    break;
 	}
     
-    dd = create_dlg (0, 0, SORT_Y, SORT_X, dialog_colors, common_dialog_callback,
-		     "[Sort Order...]", "sort", DLG_CENTER | DLG_GRID);
-		     
-    x_set_dialog_title (dd, sort_title);
+    dd = create_dlg (0, 0, SORT_Y, SORT_X, dialog_colors, NULL,
+		     "[Sort Order...]", sort_title, DLG_CENTER);
 
     add_widget (dd, 
 		button_new (10, button_pos, B_CANCEL, NORMAL_BUTTON, cancel_button, 
@@ -376,7 +370,7 @@ static int my_exit;
 static QuickWidget conf_widgets [] = {
 { quick_button,   4, 6, 4, CONFY, N_("&Cancel"),
       0, B_CANCEL, 0, 0, "c" },
-{ quick_button,   4, 6, 3, CONFY, N_("&Ok"),
+{ quick_button,   4, 6, 3, CONFY, N_("&OK"),
       0, B_ENTER, 0, 0, "o" },
 
 { quick_checkbox, 1, 13, 6, CONFY, N_(" confirm &Exit "),
@@ -391,11 +385,12 @@ static QuickWidget conf_widgets [] = {
 };
 
 static QuickDialog confirmation =
-{ CONFX, CONFY, -1, -1, N_(" Confirmation "), "[Confirmation]", "quick_confirm",
-      conf_widgets, 0 };
+    { CONFX, CONFY, -1, -1, N_(" Confirmation "), "[Confirmation]",
+    conf_widgets, 0
+};
 
 void
-confirm_box ()
+confirm_box (void)
 {
 
 #ifdef ENABLE_NLS
@@ -461,13 +456,13 @@ confirm_box ()
 static int new_mode;
 static int new_meta;
 
-char *display_bits_str [] =
+static char *display_bits_str [] =
 { N_("Full 8 bits output"), N_("ISO 8859-1"), N_("7 bits") };
 
 static QuickWidget display_widgets [] = {
 { quick_button,   4,  6,    4, DISPY, N_("&Cancel"),
       0, B_CANCEL, 0, 0, "c" },
-{ quick_button,   4,  6,    3, DISPY, N_("&Ok"),
+{ quick_button,   4,  6,    3, DISPY, N_("&OK"),
       0, B_ENTER, 0, 0, "o" },
 { quick_checkbox, 4, DISPX, 7, DISPY, N_("F&ull 8 bits input"),
       0, 0, &new_meta, 0, "u" },
@@ -478,10 +473,10 @@ static QuickWidget display_widgets [] = {
 
 static QuickDialog display_bits =
 { DISPX, DISPY, -1, -1, N_(" Display bits "), "[Display bits]",
-  "dbits", display_widgets, 0 };
+  display_widgets, 0 };
 
 void
-display_bits_box ()
+display_bits_box (void)
 {
     int current_mode;
 
@@ -548,34 +543,10 @@ display_bits_box ()
 #else /* HAVE_CHARSET */
 
 
-Dlg_head *dbits_dlg;
-
-static void dbits_refresh()
-{
-    attrset( COLOR_NORMAL );
-    dlg_erase( dbits_dlg );
-    
-    draw_box( dbits_dlg, 1, 2, dbits_dlg->lines - 2, dbits_dlg->cols - 4 );
-    
-    attrset( COLOR_HOT_NORMAL );
-    dlg_move( dbits_dlg, 1, (dbits_dlg->cols - strlen(dbits_dlg->title)) / 2 );
-    addstr( dbits_dlg->title );
-}
-
-static int dbits_callback( Dlg_head * h, int Par, int Msg )
-{
-    switch (Msg) {
-	case DLG_DRAW:
-	    dbits_refresh();
-	    break;
-    }
-    return 0;
-}
-
 static int new_display_codepage;
 
-WLabel *cplabel;
-WCheck *inpcheck;
+static WLabel *cplabel;
+static WCheck *inpcheck;
 
 static int sel_charset_button( int action, void *param )
 {
@@ -584,27 +555,27 @@ static int sel_charset_button( int action, void *param )
     cpname = (new_display_codepage < 0)
 	     ? _("Other 8 bit")
 	     : codepages[ new_display_codepage ].name;
-    sprintf( buf, "%-27s", cpname ); /* avoid strange bug with label repainting */
+    g_snprintf( buf, sizeof (buf), "%-27s", cpname ); /* avoid strange bug with label repainting */
     label_set_text( cplabel, buf );
     return 0;
 }
 
-void init_disp_bits_box()
+static Dlg_head *
+init_disp_bits_box (void)
 {
     char *cpname;
+    Dlg_head *dbits_dlg;
 
     do_refresh();
 
     dbits_dlg = create_dlg( 0, 0, DISPY, DISPX, dialog_colors,
-		dbits_callback, "[Display bits]", "Display bits",
-		DLG_CENTER );
-    x_set_dialog_title( dbits_dlg, _(" Display bits "));
+		NULL, "[Display bits]", _(" Display bits "), DLG_CENTER);
 
     add_widget( dbits_dlg,
 		label_new( 3, 4, _("Input / display codepage:"), NULL));
 
     cpname = (new_display_codepage < 0)
-	     ? "Other 8 bit"
+	     ? _("Other 8 bit")
 	     : codepages[ new_display_codepage ].name;
     cplabel = label_new( 4, 4, cpname, NULL);
     add_widget( dbits_dlg, cplabel );
@@ -614,7 +585,7 @@ void init_disp_bits_box()
 			    NORMAL_BUTTON, _("&Cancel"), 0, 0, NULL ) );
     add_widget( dbits_dlg,
 		button_new( DISPY - 3, 7, B_ENTER,
-			    NORMAL_BUTTON, _("&Ok"), 0, 0, NULL ) );
+			    NORMAL_BUTTON, _("&OK"), 0, 0, NULL ) );
 
     inpcheck = check_new( 6, 4, !use_8th_bit_as_meta,
 			  _("F&ull 8 bits input"), NULL );
@@ -625,16 +596,20 @@ void init_disp_bits_box()
 		button_new( 4, DISPX - 8 - strlen(cpname) , B_USER,
 			    NORMAL_BUTTON, cpname,
 			    sel_charset_button, 0, NULL ) );
+
+    return dbits_dlg;
 }
 
-void display_bits_box()
+void
+display_bits_box (void)
 {
+    Dlg_head *dbits_dlg;
     new_display_codepage = display_codepage;
 
     application_keypad_mode ();
-    init_disp_bits_box();
+    dbits_dlg = init_disp_bits_box ();
 
-    run_dlg( dbits_dlg );
+    run_dlg (dbits_dlg);
 
     if (dbits_dlg->ret_value == B_ENTER) {
 	char *errmsg;
@@ -660,8 +635,6 @@ void display_bits_box()
 #define TREE_Y 20
 #define TREE_X 60
 
-static int tree_colors [4];
-
 static int
 tree_callback (struct Dlg_head *h, int id, int msg)
 {
@@ -669,7 +642,7 @@ tree_callback (struct Dlg_head *h, int id, int msg)
 
     case DLG_POST_KEY:
 	/* The enter key will be processed by the tree widget */
-	if (id == '\n' || ((WTree *)(h->current->widget))->done){
+	if (id == '\n') {
 	    h->ret_value = B_ENTER;
 	    dlg_stop (h);
 	}
@@ -682,20 +655,18 @@ tree_callback (struct Dlg_head *h, int id, int msg)
     return MSG_NOT_HANDLED;
 }
 
+/* Show tree in a box, not on a panel */
 char *
-tree (char *current_dir)
+tree_box (char *current_dir)
 {
     WTree    *mytree;
     Dlg_head *dlg;
     char     *val;
     WButtonBar *bar;
 
-    tree_colors [3] = dialog_colors [0];
-    tree_colors [1] = dialog_colors [1];
-    
     /* Create the components */
-    dlg = create_dlg (0, 0, TREE_Y, TREE_X, tree_colors,
-		      tree_callback, "[Directory Tree]", "tree", DLG_CENTER);
+    dlg = create_dlg (0, 0, TREE_Y, TREE_X, dialog_colors,
+		      tree_callback, "[Directory Tree]", NULL, DLG_CENTER);
     mytree = tree_new (0, 2, 2, TREE_Y - 6, TREE_X - 5);
     add_widget (dlg, mytree);
     bar = buttonbar_new(1);
@@ -705,7 +676,7 @@ tree (char *current_dir)
     
     run_dlg (dlg);
     if (dlg->ret_value == B_ENTER)
-	val = g_strdup (mytree->selected_ptr->name);
+	val = g_strdup (tree_selected_name (mytree));
     else
 	val = 0;
     
@@ -716,22 +687,15 @@ tree (char *current_dir)
 #ifdef USE_VFS
 
 #if defined(USE_NETCODE)
-#define VFSY 14
+#define VFSY 16
+#define VFS_WIDGETBASE 9
 #else
 #define VFSY 8
+#define VFS_WIDGETBASE 0
 #endif
 
 #define VFSX 56
 
-extern int vfs_timeout;
-extern int ftpfs_always_use_proxy;
-
-#if defined(USE_NETCODE)
-extern char *ftpfs_anonymous_passwd;
-extern char *ftpfs_proxy_host;
-extern int use_netrc;
-#endif
-
 static char *ret_timeout;
 
 #if defined(USE_NETCODE)
@@ -739,20 +703,19 @@ static char *ret_passwd;
 static char *ret_directory_timeout;
 static char *ret_ftp_proxy;
 static int ret_use_netrc;
-#endif
-
-#if 0
-/* Not used currently */
-{ quick_checkbox,  4, VFSX, 10, VFSY, "Use ~/.netrc",
-      'U', 0, 0, &ret_use_netrc, 0, "" },
+static int ret_ftpfs_use_passive_connections;
 #endif
 
 static QuickWidget confvfs_widgets [] = {
 { quick_button,   30,  VFSX,    VFSY - 3, VFSY, N_("&Cancel"),
       0, B_CANCEL, 0, 0, "button-cancel" },
-{ quick_button,   12, VFSX,    VFSY - 3, VFSY, N_("&Ok"),
+{ quick_button,   12, VFSX,    VFSY - 3, VFSY, N_("&OK"),
       0, B_ENTER, 0, 0, "button-ok" },
 #if defined(USE_NETCODE)
+{ quick_checkbox,  4, VFSX, 11, VFSY, N_("Use &passive mode"), 0, 0,
+      &ret_ftpfs_use_passive_connections, 0, "check-use-passive-mode" },
+{ quick_checkbox,  4, VFSX, 10, VFSY, N_("&Use ~/.netrc"), 0, 0,
+      &ret_use_netrc, 0, "check-use-netrc" },
 { quick_input,     4, VFSX, 9, VFSY, "", 48, 0, 0, &ret_ftp_proxy,
       "input-ftp-proxy" },
 { quick_checkbox,  4, VFSX, 8, VFSY, N_("&Always use ftp proxy"), 0, 0,
@@ -778,13 +741,8 @@ static QuickWidget confvfs_widgets [] = {
 };
 
 static QuickDialog confvfs_dlg =
-{ VFSX, VFSY, -1, -1, N_(" Virtual File System Setting "), "[Virtual FS]", "quick_vfs", confvfs_widgets, 0 };
-
-#if defined(USE_NETCODE)
-#define VFS_WIDGETBASE 7
-#else
-#define VFS_WIDGETBASE 0
-#endif
+    { VFSX, VFSY, -1, -1, N_(" Virtual File System Setting "),
+"[Virtual FS]", confvfs_widgets, 0 };
 
 void
 configure_vfs (void)
@@ -792,17 +750,16 @@ configure_vfs (void)
     char buffer2[BUF_TINY];
 #if defined(USE_NETCODE)
     char buffer3[BUF_TINY];
-#endif
 
+    ret_use_netrc = use_netrc;
+    ret_ftpfs_use_passive_connections = ftpfs_use_passive_connections;
+    g_snprintf(buffer3, sizeof (buffer3), "%i", ftpfs_directory_timeout);
+    confvfs_widgets[7].text = buffer3;
+    confvfs_widgets[9].text = ftpfs_anonymous_passwd;
+    confvfs_widgets[4].text = ftpfs_proxy_host;
+#endif
     g_snprintf (buffer2, sizeof (buffer2), "%i", vfs_timeout);
     confvfs_widgets [3 + VFS_WIDGETBASE].text = buffer2;
-#if defined(USE_NETCODE)
-    ret_use_netrc = use_netrc;
-    g_snprintf(buffer3, sizeof (buffer3), "%i", ftpfs_directory_timeout);
-    confvfs_widgets[5].text = buffer3;
-    confvfs_widgets[7].text = ftpfs_anonymous_passwd;
-    confvfs_widgets[2].text = ftpfs_proxy_host;
-#endif
 
     if (quick_dialog (&confvfs_dlg) != B_CANCEL) {
         vfs_timeout = atoi (ret_timeout);
@@ -817,40 +774,38 @@ configure_vfs (void)
 	ftpfs_proxy_host = ret_ftp_proxy;
 	ftpfs_directory_timeout = atoi(ret_directory_timeout);
 	use_netrc = ret_use_netrc;
+	ftpfs_use_passive_connections = ret_ftpfs_use_passive_connections;
 	g_free (ret_directory_timeout);
 #endif
     }
 }
 
-#endif
+#endif	/* USE_VFS */
 
 char *
 cd_dialog (void)
 {
     QuickDialog Quick_input;
     QuickWidget quick_widgets [] = {
-    { quick_input,  6, 57, 5, 0, "", 50, 0, 0, 0, "input" },
-    { quick_label,  3, 57, 2, 0, "",  0, 0, 0, 0, "label" },
-    { 0 } };
-    
+	{ quick_input,  6, 57, 2, 0, "", 50, 0, 0, 0, "input" },
+	{ quick_label,  3, 57, 2, 0, "",  0, 0, 0, 0, "label" },
+	{ 0 }
+    };
     char *my_str;
-	int len;
-    
+    int len;
+
     Quick_input.xlen  = 57;
     Quick_input.title = _("Quick cd");
     Quick_input.help  = "[Quick cd]";
-    Quick_input.class = "quick_input";
-    quick_widgets [0].text = "";
     quick_widgets [0].value = 2; /* want cd like completion */
     quick_widgets [1].text = _("cd");
     quick_widgets [1].y_divisions =
 	quick_widgets [0].y_divisions = Quick_input.ylen = 5;
 
-	len = strlen (quick_widgets [1].text);
+    len = strlen (quick_widgets [1].text);
 
-	quick_widgets [1].relative_x = 3;
-	quick_widgets [0].relative_x = 
-		quick_widgets [1].relative_x + len + 1;
+    quick_widgets [0].relative_x =
+	quick_widgets [1].relative_x + len + 1;
 
     Quick_input.xlen = len + quick_widgets [0].hotkey_pos + 7;
 	quick_widgets [0].x_divisions =
@@ -859,12 +814,11 @@ cd_dialog (void)
     Quick_input.i18n = 1;
     Quick_input.xpos = 2;
     Quick_input.ypos = LINES - 2 - Quick_input.ylen;
-    quick_widgets [0].relative_y = 2;
     quick_widgets [0].str_result = &my_str;
     
     Quick_input.widgets = quick_widgets;
     if (quick_dialog (&Quick_input) != B_CANCEL){
-	return *(quick_widgets [0].str_result);
+	return my_str;
     } else
 	return 0;
 }
@@ -884,7 +838,6 @@ symlink_dialog (char *existing, char *new, char **ret_existing, char **ret_new)
     Quick_input.ylen  = 8;
     Quick_input.title = _("Symbolic link");
     Quick_input.help  = "[File Menu]";
-    Quick_input.class = "quick_symlink";
     Quick_input.i18n  = 0;
     quick_widgets [0].text = new;
     quick_widgets [1].text = _("Symbolic link filename:");
@@ -983,7 +936,7 @@ job_buttons [] =
 	{N_("&Stop"),   3,  B_STOP,   task_cb, "button-stop"},
 	{N_("&Resume"), 12, B_RESUME, task_cb, "button-cont"},
 	{N_("&Kill"),   23, B_KILL,   task_cb, "button-kill"},
-	{N_("&Ok"),     35, B_CANCEL, NULL,    "button-ok"},
+	{N_("&OK"),     35, B_CANCEL, NULL,    "button-ok"},
 };
 
 void
@@ -1018,11 +971,10 @@ jobs_cmd (void)
 	}
 #endif /* ENABLE_NLS */
 
-    jobs_dlg = create_dlg (0, 0, JOBS_Y, JOBS_X, dialog_colors,
-			   common_dialog_callback, "[Background jobs]", "jobs",
-			   DLG_CENTER | DLG_GRID);
-    x_set_dialog_title (jobs_dlg, _("Background Jobs"));
-    
+    jobs_dlg = create_dlg (0, 0, JOBS_Y, JOBS_X, dialog_colors, NULL,
+			   "[Background jobs]", _("Background Jobs"),
+			   DLG_CENTER);
+
     bg_list = listbox_new (2, 3, JOBS_X-7, JOBS_Y-9, listbox_nothing, 0, "listbox");
     add_widget (jobs_dlg, bg_list);
 
@@ -1050,12 +1002,12 @@ vfs_smb_get_authinfo (const char *host, const char *share, const char *domain,
 		      const char *user)
 {
     static int dialog_x = 44;
-    int dialog_y = 12;
+    enum { b0 = 3, dialog_y = 12};
     struct smb_authinfo *return_value;
-    static char* labs[] = {N_("Domain:"), N_("Username:"), N_("Password: ")};
-    static char* buts[] = {N_("&Ok"), N_("&Cancel")};
+    static char* labs[] = {N_("Domain:"), N_("Username:"), N_("Password:")};
+    static char* buts[] = {N_("&OK"), N_("&Cancel")};
     static int ilen = 30, istart = 14;
-    static int b0 = 3, b2 = 30;
+    static int b2 = 30;
     char *title;
     WInput *in_password;
     WInput *in_user;
@@ -1103,12 +1055,11 @@ vfs_smb_get_authinfo (const char *host, const char *share, const char *domain,
     if (!user)
     user = "";
 
-    auth_dlg = create_dlg (0, 0, dialog_y, dialog_x, dialog_colors,
-                       common_dialog_callback, "[Smb Authinfo]", "smbauthinfo",
-                       DLG_CENTER | DLG_GRID);
-
     title = g_strdup_printf (_("Password for \\\\%s\\%s"), host, share);
-    x_set_dialog_title (auth_dlg, title);
+
+    auth_dlg = create_dlg (0, 0, dialog_y, dialog_x, dialog_colors, NULL,
+			   "[Smb Authinfo]", title, DLG_CENTER);
+
     g_free (title);
 
     in_user  = input_new (5, istart, INPUT_COLOR, ilen, user, "auth_name");
