@@ -26,39 +26,11 @@
 #   include <unistd.h>
 #endif
 
-/* unistd.h defines _POSIX_VERSION on POSIX.1 systems. */
-#if defined(HAVE_DIRENT_H) || defined(_POSIX_VERSION)
-# ifdef NEEDS_LOCAL_DIRENT_H
-#   include "dirent.h"
-# else
-#   include <dirent.h>
-# endif
-#   define NLENGTH(dirent) (strlen ((dirent)->d_name))
-#else
-#   define dirent direct
-#   define NLENGTH(dirent) ((dirent)->d_namlen)
-
-#   ifdef HAVE_SYS_NDIR_H
-#       include <sys/ndir.h>
-#   endif /* HAVE_SYS_NDIR_H */
-
-#   ifdef HAVE_SYS_DIR_H
-#       include <sys/dir.h>
-#   endif /* HAVE_SYS_DIR_H */
-
-#   ifdef HAVE_NDIR_H
-#       include <ndir.h>
-#   endif /* HAVE_NDIR_H */
-#endif /* not (HAVE_DIRENT_H or _POSIX_VERSION) */
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifndef HAS_NO_GRP_PWD_H
-#   include <pwd.h>
-#endif
 
-#include "tty.h"
 #include "global.h"
-#include "x.h"
+#include "tty.h"
 #include "win.h"
 #include "color.h"
 #include "dlg.h"
@@ -227,7 +199,7 @@ filename_completion_function (char *text, int state)
 
 /* We assume here that text[0] == '~' , if you want to call it in another way,
    you have to change the code */
-#ifdef OS2_NT
+#ifdef NATIVE_WIN32
 char *username_completion_function (char *text, int state)
 {
     return NULL;
@@ -266,7 +238,7 @@ username_completion_function (char *text, int state)
 }
 
 extern char **environ;
-#endif /* OS2_NT */
+#endif /* NATIVE_WIN32 */
 
 /* We assume text [0] == '$' and want to have a look at text [1], if it is
    equal to '{', so that we should append '}' at the end */
@@ -807,11 +779,9 @@ void free_completions (WInput *in)
     in->completions = NULL;
 }
 
-#ifndef HAVE_GNOME
 static int query_height, query_width;
 static WInput *input;
 static int min_end;
-#endif /* !HAVE_GNOME */
 static int start, end;
 
 static int insert_text (WInput *in, char *text, int len)
@@ -827,8 +797,8 @@ static int insert_text (WInput *in, char *text, int len)
     }
     if (strlen (in->buffer)+1 < in->current_max_len){
     	if (len > 0){
-	    int i, l = strlen (&in->buffer [end]);
-	    for (i = l + 1; i >= 0; i--)
+	    int i = strlen (&in->buffer [end]);
+	    for (; i >= 0; i--)
 	        in->buffer [end + len + i] = in->buffer [end + i];
 	} else if (len < 0){
 	    char *p = in->buffer + end + len, *q = in->buffer + end;
@@ -844,102 +814,106 @@ static int insert_text (WInput *in, char *text, int len)
     return len != 0;
 }
 
-#ifndef HAVE_GNOME
-static int query_callback (Dlg_head * h, int Par, int Msg)
+static int
+query_callback (Dlg_head * h, int Par, int Msg)
 {
     switch (Msg) {
-    	case DLG_DRAW:
-    	    attrset (COLOR_NORMAL);
-	    dlg_erase (h);
-    	    draw_box (h, 0, 0, query_height, query_width);
-    	    break;
-    	    
-    	case DLG_KEY:
-	    switch (Par) {
-		case KEY_LEFT:
-		case KEY_RIGHT:
-	    	    h->ret_value = 0;
-		    dlg_stop (h);
-	    	    return 1;
-	    	    
-	    	case 0177:
-	    	case KEY_BACKSPACE:
-	    	case XCTRL('h'):
-	    	    if (end == min_end){
-	    	    	h->ret_value = 0;
-			dlg_stop (h);
-	    	    	return 1;
-	    	    } else {
-	    	    	WLEntry *e, *e1;
-	    	    	
-	    	    	e1 = e = ((WListbox *)(h->current->widget))->list;
-	    	    	do {
-	    	    	    if (!strncmp (input->buffer + start, e1->text, end - start - 1)){
-	    	    	    	listbox_select_entry((WListbox *)(h->current->widget), e1);
-	    	    	    	handle_char (input, Par);
-	    	    	    	end--;
-				send_message (h, h->current->widget,
-				    WIDGET_DRAW, 0);
-	    	    	    	break;
-	    	    	    }
-	    	    	    e1 = e1->next;
-	    	    	} while (e != e1);
-	    	    }
-	    	    return 1;
-	    	    
-                default:
-	    	    if (Par > 0xff || !is_printable (Par)){
-	    	    	if (is_in_input_map (input, Par) == 2){
-	    	    	    if (end == min_end)
-	    	    	        return 1;
-	    	    	    h->ret_value = B_USER; /* This means we want to refill the
-	    	    	         	              list box and start again */
-			    dlg_stop (h);
-	    	    	    return 1;
-	    	    	} else
-	    	    	    return 0;
-	    	    } else {
-	    	    	WLEntry *e, *e1;
-	    	    	int need_redraw = 0;
-	    	    	int low = 4096;
-	    	    	char *last_text = NULL;
-	    	    	
-	    	    	e1 = e = ((WListbox *)(h->current->widget))->list;
-	    	    	do {
-	    	    	    if (!strncmp (input->buffer + start, e1->text, end - start)){
-	    	    	        if (e1->text [end - start] == Par){
-	    	    	            if (need_redraw){
-	    	    	            	register int c1, c2, si;
-	    	    	            	
-					for (si = end - start + 1; 
-					     (c1 = last_text [si]) &&
-					     (c2 = e1->text [si]); si++)
-		    			    if (c1 != c2)
-		    			    	break;
-	        			if (low > si) 
-	        			    low = si;
-					last_text = e1->text;
-					need_redraw = 2;
-	    	    	            } else {
-	    	    	            	need_redraw = 1;
-	    	    	    	    	listbox_select_entry((WListbox *)(h->current->widget), e1);
-	    	    	    	    	last_text = e1->text;
-	    	    	    	    }
-	    	    	        }
-	    	    	    }
-	    	    	    e1 = e1->next;
-	    	    	} while (e != e1);
-	    	    	if (need_redraw == 2){
-	    	    	    insert_text (input, last_text, low);
-	    	    	    send_message (h, h->current->widget,WIDGET_DRAW,0);
-	    	    	} else if (need_redraw == 1){
-	    	    	    h->ret_value = B_ENTER;
-			    dlg_stop (h);
-	    	    	}
-	    	    }
-	    	    return 1;
+    case DLG_DRAW:
+	common_dialog_repaint (h);
+	break;
+
+    case DLG_KEY:
+	switch (Par) {
+	case KEY_LEFT:
+	case KEY_RIGHT:
+	    h->ret_value = 0;
+	    dlg_stop (h);
+	    return 1;
+
+	case 0177:
+	case KEY_BACKSPACE:
+	case XCTRL ('h'):
+	    if (end == min_end) {
+		h->ret_value = 0;
+		dlg_stop (h);
+		return 1;
+	    } else {
+		WLEntry *e, *e1;
+
+		e1 = e = ((WListbox *) (h->current->widget))->list;
+		do {
+		    if (!strncmp
+			(input->buffer + start, e1->text,
+			 end - start - 1)) {
+			listbox_select_entry ((WListbox *) (h->current->
+							    widget), e1);
+			handle_char (input, Par);
+			end--;
+			send_message (h->current->widget, WIDGET_DRAW, 0);
+			break;
+		    }
+		    e1 = e1->next;
+		} while (e != e1);
 	    }
-	    break;
+	    return 1;
+
+	default:
+	    if (Par > 0xff || !is_printable (Par)) {
+		if (is_in_input_map (input, Par) == 2) {
+		    if (end == min_end)
+			return 1;
+		    h->ret_value = B_USER;	/* This means we want to refill the
+						   list box and start again */
+		    dlg_stop (h);
+		    return 1;
+		} else
+		    return 0;
+	    } else {
+		WLEntry *e, *e1;
+		int need_redraw = 0;
+		int low = 4096;
+		char *last_text = NULL;
+
+		e1 = e = ((WListbox *) (h->current->widget))->list;
+		do {
+		    if (!strncmp
+			(input->buffer + start, e1->text, end - start)) {
+			if (e1->text[end - start] == Par) {
+			    if (need_redraw) {
+				register int c1, c2, si;
+
+				for (si = end - start + 1;
+				     (c1 = last_text[si]) &&
+				     (c2 = e1->text[si]); si++)
+				    if (c1 != c2)
+					break;
+				if (low > si)
+				    low = si;
+				last_text = e1->text;
+				need_redraw = 2;
+			    } else {
+				need_redraw = 1;
+				listbox_select_entry ((WListbox *) (h->
+								    current->
+								    widget),
+						      e1);
+				last_text = e1->text;
+			    }
+			}
+		    }
+		    e1 = e1->next;
+		} while (e != e1);
+		if (need_redraw == 2) {
+		    insert_text (input, last_text, low);
+		    send_message (h->current->widget, WIDGET_DRAW, 0);
+		} else if (need_redraw == 1) {
+		    h->ret_value = B_ENTER;
+		    dlg_stop (h);
+		}
+	    }
+	    return 1;
+	}
+	break;
     }
     return 0;
 }
@@ -948,7 +922,6 @@ static int querylist_callback (void *data)
 {
     return 1;
 }
-#endif /* !HAVE_GNOME */
 
 #define DO_INSERTION 1
 #define DO_QUERY     2
@@ -981,7 +954,6 @@ complete_engine (WInput *in, int what_to_do)
 	 * because we do not have a Gtk dialog for it.  Gtk-ted does not like
 	 * this; if we enable this code, it will crash.
 	 */
-#ifndef HAVE_GNOME
     	if ((what_to_do & DO_QUERY) && in->completions [1]) {
     	    int maxlen = 0, i, count = 0;
     	    int x, y, w, h;
@@ -1021,7 +993,7 @@ complete_engine (WInput *in, int what_to_do)
 	    query_width  = w;
     	    query_dlg = create_dlg (y, x, query_height, query_width,
 				    dialog_colors, query_callback,
-				    "[Completion]", "complete", DLG_NONE);
+				    "[Completion]", NULL, DLG_COMPACT);
     	    query_list = listbox_new (1, 1, w - 2, h - 2, 0, querylist_callback, NULL);
     	    add_widget (query_dlg, query_list);
     	    for (p = in->completions + 1; *p; p++)
@@ -1040,10 +1012,6 @@ complete_engine (WInput *in, int what_to_do)
     	    if (i == B_USER)
     	    	return 1;
     	}
-#else
-	if (what_to_do & DO_QUERY)
-	    beep ();
-#endif
     } else
     	beep ();
     return 0;
