@@ -14,6 +14,8 @@
 #include "eregex.h"
 
 
+typedef int (*mc_stat_fn) (char *filename, struct stat *buf);
+
 /* This structure describes a context for file operations.  It is used to update
  * the progress windows and pass around options.
  */
@@ -31,7 +33,7 @@ typedef struct {
 	int progress_totals_computed;
 
 	/* Counters for progress indicators */
-	long progress_count;
+	off_t progress_count;
 	double progress_bytes;
 
 	/* The value of the "preserve Attributes" checkbox in the copy file dialog.
@@ -54,7 +56,7 @@ typedef struct {
 	int follow_links;
 
 	/* Pointer to the stat function we will use */
-	int (*stat_func) (char *filename, struct stat *buf);
+	mc_stat_fn stat_func;
 
 	/* Whether to recompute symlinks */
 	int stable_symlinks;
@@ -65,7 +67,7 @@ typedef struct {
 	int preserve;
 
 	/* If running as root, preserve the original uid/gid (we don't want to
-	 * try chwon for non root) preserve_uidgid = preserve && uid == 0
+	 * try chown for non root) preserve_uidgid = preserve && uid == 0
 	 */
 	int preserve_uidgid;
 
@@ -120,6 +122,14 @@ typedef enum {
 	FILE_ABORT
 } FileProgressStatus;
 
+typedef enum {
+    RECURSIVE_YES,
+    RECURSIVE_NO,
+    RECURSIVE_ALWAYS,
+    RECURSIVE_NEVER,
+    RECURSIVE_ABORT
+} FileCopyMode;
+
 /* First argument passed to real functions */
 enum OperationMode {
     Foreground,
@@ -131,8 +141,8 @@ enum OperationMode {
 void file_op_context_create_ui (FileOpContext *ctx, FileOperation op, int with_eta);
 void file_op_context_destroy_ui (FileOpContext *ctx);
 
-FileProgressStatus file_progress_show (FileOpContext *ctx, long done, long total);
-FileProgressStatus file_progress_show_count (FileOpContext *ctx, long done, long total);
+FileProgressStatus file_progress_show (FileOpContext *ctx, off_t done, off_t total);
+FileProgressStatus file_progress_show_count (FileOpContext *ctx, off_t done, off_t total);
 FileProgressStatus file_progress_show_bytes (FileOpContext *ctx, double done, double total);
 FileProgressStatus file_progress_show_source (FileOpContext *ctx, char *path);
 FileProgressStatus file_progress_show_target (FileOpContext *ctx, char *path);
