@@ -6,20 +6,19 @@
 #include "config.h"
 #endif
 
+#include "poptalloca.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
 #ifdef __NeXT
 /* access macros are not declared in non posix mode in unistd.h -
  don't try to use posix on NeXTstep 3.3 ! */ 
 #include <libc.h>
 #endif
 
-#if HAVE_ALLOCA_H
-# include <alloca.h>
-#endif
-
 #include "findme.h"
 
 char * findProgramPath(char * argv0) {
