@@ -2,15 +2,42 @@
 
 #ifndef __FS_H
 #define __FS_H
+
 #include <sys/types.h>
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
 #endif
-#ifdef HAVE_SYS_PARAM_H
-#   include <sys/param.h>
-#endif
 #include <sys/stat.h>
 
+
+/* Replacement for permission bits missing in sys/stat.h */
+#ifndef S_ISLNK
+#   define S_ISLNK(x) 0
+#endif
+
+#ifndef S_ISSOCK
+#   define S_ISSOCK(x) 0
+#endif
+
+#ifndef S_ISFIFO
+#   define S_ISFIFO(x) 0
+#endif
+
+#ifndef S_ISCHR
+#   define S_ISCHR(x) 0
+#endif
+
+#ifndef S_ISBLK
+#   define S_ISBLK(x) 0
+#endif
+
+/* Door is something that only exists on Solaris */
+#ifndef S_ISDOOR
+#   define S_ISDOOR(x) 0
+#endif
+
+
+
 #ifndef MAXPATHLEN
 #   define MC_MAXPATHLEN 4096
 #else
@@ -18,12 +45,12 @@
 #endif
 
 /* unistd.h defines _POSIX_VERSION on POSIX.1 systems. */
-#if defined(HAVE_DIRENT_H) || defined(_POSIX_VERSION)
-# ifdef NEEDS_LOCAL_DIRENT_H
-#   include "dirent.h"
-# else
+#ifdef HAVE_DIRENT_H
 #   include <dirent.h>
-# endif
+#   define NLENGTH(dirent) (strlen ((dirent)->d_name))
+#   define DIRENT_LENGTH_COMPUTED 1
+#elif defined(_MSC_VER)
+/* dirent provided by glib */
 #   define NLENGTH(dirent) (strlen ((dirent)->d_name))
 #   define DIRENT_LENGTH_COMPUTED 1
 #else
@@ -43,4 +70,12 @@
 #   endif /* HAVE_NDIR_H */
 #endif /* not (HAVE_DIRENT_H or _POSIX_VERSION) */
 
+static inline void compute_namelen(struct dirent* dent) {
+#ifdef DIRENT_LENGTH_COMPUTED
+    return;
+#else
+    dent->d_namlen = strlen (dent);
 #endif
+}
+
+#endif /* !__FS_H */
