@@ -23,33 +23,31 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
-#include <sys/param.h>		/* Required by tree.h */
 #include <sys/types.h>
 #include <sys/stat.h>
-#if (!defined(__IBMC__) && !defined(__IBMCPP__)) && !defined(HAS_NO_TERMIOS_H)
+#if HAVE_TERMIOS_H
 #    include <termios.h>
 #endif
      /*
       * If TIOCGWINSZ supported, make it available here, because window-
       * resizing code depends on it...
       */
-#if (!defined(__IBMC__) && !defined(__IBMCPP__)) && !defined(HAS_NO_SYS_IOCTL_H)
-#	include <sys/ioctl.h>
+#ifdef HAVE_SYS_IOCTL_H
+#   include <sys/ioctl.h>
 #endif
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
 #endif
 #include <signal.h>
-#include "tty.h"
+
 #include "global.h"
+#include "tty.h"		/* COLS */
 #include "win.h"
 #include "color.h"
 #include "key.h"
-
 #include "dlg.h"
 #include "widget.h"
 #include "command.h"
-
 #include "dialog.h"		/* For do_refresh() */
 #include "profile.h"		/* For sync_profiles() */
 #include "mouse.h"
@@ -62,7 +60,6 @@
 /* Needed for the extern declarations of integer parameters */
 #include "dir.h"
 #include "panel.h"		/* The Panel widget */
-#include "file.h"
 #include "cons.saver.h"
 #include "layout.h"
 #include "info.h"		/* The Info widget */
@@ -71,10 +68,6 @@
 #define WANT_WIDGETS
 #include "setup.h"		/* For save_setup() */
 
-#include "x.h"
-
-/* "$Id: layout.c,v 1.27 2001/08/21 06:32:41 proskin Exp $" */
-
 /* Controls the display of the rotating dash on the verbose mode */
 int nice_rotating_dash = 1;
 
@@ -105,8 +98,8 @@ int keybar_visible = 1;
 /* Set if the nice message (hint) bar is visible */
 int message_visible = 1;
 
-/* Set if you want the message bar shown in xterm title bar to save space */
-int xterm_hintbar = 0;
+/* Set to show current working dir in xterm window title */
+int xterm_title = 1;
 
 /* The starting line for the output of the subprogram */
 int output_start_y = 0;
@@ -116,7 +109,7 @@ int output_start_y = 0;
 /* Janne gets around this, we will only manage two of them :-) */
 #define MAX_VIEWS 2
 
-struct {
+static struct {
     int    type;
     Widget *widget;
 } panels [MAX_VIEWS];
@@ -136,7 +129,7 @@ static int _output_lines;
 static int _command_prompt;
 static int _keybar_visible;
 static int _message_visible;
-static int _xterm_hintbar;
+static int _xterm_title;
 static int _permission_mode;
 static int _filetype_mode;
 
@@ -159,7 +152,8 @@ static char *s_split_direction [2] = {
     N_("&Vertical"), 
     N_("&Horizontal")
 };
-WRadio *radio_widget;
+
+static WRadio *radio_widget;
 
 static struct {
     char   *text;
@@ -167,7 +161,7 @@ static struct {
     WCheck *widget;
     char   *tkname;
 } check_options [] = {
-    { N_("&Xterm hintbar"),    &xterm_hintbar,   0, "h" },
+    { N_("&Xterm window title"), &xterm_title,   0, "t" },
     { N_("h&Intbar visible"),  &message_visible, 0, "v" },
     { N_("&Keybar visible"),   &keybar_visible,  0, "k" },
     { N_("command &Prompt"),   &command_prompt,  0, "p" },
@@ -180,7 +174,7 @@ static struct {
 };
 
 static int first_width, second_width;
-static char *layout_title, *title1, *title2, *title3, *output_lines_label;
+static char *title1, *title2, *title3, *output_lines_label;
 
 static WButton *bleft_widget, *bright_widget;
 
@@ -277,19 +271,18 @@ static int layout_callback (struct Dlg_head *h, int Id, int Msg)
     case DLG_DRAW:
     	/*When repainting the whole dialog (e.g. with C-l) we have to
     	  update everything*/
+	common_dialog_repaint (h);
+
    	old_first_panel_size = -1;
     	old_horizontal_split = -1;
     	old_output_lines     = -1;
+
 	attrset (COLOR_NORMAL);
-	dlg_erase (h);
-	draw_box (h, 1, 2, h->lines - 2, h->cols - 4);
 	draw_box (h, 2, 4, 6, first_width);
 	draw_box (h, 8, 4, 4, first_width);
 	draw_box (h, 2, 5 + first_width, 10, second_width);
 
 	attrset (COLOR_HOT_NORMAL);
-	dlg_move (h, 1, (h->cols - strlen(layout_title))/2);
-	addstr (layout_title);
 	dlg_move (h, 2, 5);
 	addstr (title1);
 	dlg_move (h, 8, 5);
@@ -319,14 +312,13 @@ static int layout_callback (struct Dlg_head *h, int Id, int Msg)
 	_command_prompt = check_options [4].widget->state & C_BOOL;
 	_keybar_visible = check_options [2].widget->state & C_BOOL;
 	_message_visible = check_options [1].widget->state & C_BOOL;
-	_xterm_hintbar = check_options [0].widget->state & C_BOOL;
+	_xterm_title = check_options [0].widget->state & C_BOOL;
 	if (console_flag){
 	    int minimum;
 	    if (_output_lines < 0)
 		_output_lines = 0;
 	    height = LINES - _keybar_visible - _command_prompt -
 		     _menubar_visible - _output_lines - _message_visible;
-	    if (_message_visible && _xterm_hintbar && xterm_flag) height++;
 	    minimum = MINHEIGHT * (1 + _horizontal_split);
 	    if (height < minimum){
 		_output_lines -= minimum - height;
@@ -335,7 +327,6 @@ static int layout_callback (struct Dlg_head *h, int Id, int Msg)
 	} else {
 	    height = LINES - _keybar_visible - _command_prompt -
 		_menubar_visible - _output_lines - _message_visible;
-	    if (_message_visible && _xterm_hintbar && xterm_flag) height++;
 	}
 	if (_horizontal_split != radio_widget->sel){
 	    _horizontal_split = radio_widget->sel;
@@ -366,7 +357,7 @@ static void init_layout (void)
     static int i18n_layt_flag = 0;
 	static int b1, b2, b3;
     int i = sizeof (s_split_direction) / sizeof(char*) ;
-	char* ok_button = _("&Ok");
+	char* ok_button = _("&OK");
 	char* cancel_button = _("&Cancel");
 	char* save_button = _("&Save");
     
@@ -376,7 +367,6 @@ static void init_layout (void)
 		
 		first_width = 19; /* length of line with '<' '>' buttons */
 		
-		layout_title = _(" Layout ");
 		title1 = _(" Panel split ");
 		title2 = _(" Highlight... ");
 		title3 = _(" Other options ");
@@ -424,7 +414,7 @@ static void init_layout (void)
 
 		/* 
 		 * alex@bcs.zp.ua:
-		 * To be completely correct, one need to check if layout_title
+		 * To be completely correct, one need to check if the title
 		 * does not exceed dialog length and total length of 3 buttons
 		 * allows their placement in one row. But assuming this dialog
 		 * is wide enough, I don't include such a tests.
@@ -445,9 +435,7 @@ static void init_layout (void)
 
     layout_dlg = create_dlg (0, 0, 15, first_width + second_width + 9, 
 		dialog_colors, layout_callback,
-		"[Layout]", "layout", DLG_CENTER | DLG_GRID);
-			     
-    x_set_dialog_title (layout_dlg, _("Layout"));
+		"[Layout]", _("Layout"), DLG_CENTER);
 
     add_widget (layout_dlg,
 		button_new (BY, b3, B_CANCEL, NORMAL_BUTTON, cancel_button, 0, 0, "c"));
@@ -482,7 +470,7 @@ static void init_layout (void)
     _command_prompt = command_prompt;
     _keybar_visible = keybar_visible;
     _message_visible = message_visible;
-    _xterm_hintbar = xterm_hintbar;
+    _xterm_title = xterm_title;
     bright_widget = button_new(6, 15, B_2RIGHT, NARROW_BUTTON, "&>", b2right_cback, 0, ">");
     add_widget (layout_dlg, bright_widget);
     bleft_widget = button_new (6, 9, B_2LEFT, NARROW_BUTTON, "&<", b2left_cback, 0, "<");
@@ -558,16 +546,10 @@ static void check_split (void)
     }
 }
 
-int panel_event    (Gpm_Event *event, WPanel *panel);
-int menu_bar_event (Gpm_Event *event, void *);
-extern char *prompt;
-
 #ifdef HAVE_SLANG
-void init_curses ()
+void
+init_curses ()
 {
-    extern int force_ugly_line_drawing;
-    extern int SLtt_Has_Alt_Charset;
-    SLtt_get_terminfo ();
 #ifndef HAS_ACS_AS_PCCHARS
     if (force_ugly_line_drawing)
 	SLtt_Has_Alt_Charset = 0;
@@ -579,36 +561,63 @@ void init_curses ()
     nodelay (stdscr, FALSE);
 }
 #else
+static const struct {
+    int acscode;
+    int character;
+} acs_approx [] = {
+    { 'q',  '-' }, /* ACS_HLINE */
+    { 'x',  '|' }, /* ACS_VLINE */
+    { 'l',  '+' }, /* ACS_ULCORNER */
+    { 'k',  '+' }, /* ACS_URCORNER */
+    { 'm',  '+' }, /* ACS_LLCORNER */
+    { 'j',  '+' }, /* ACS_LRCORNER */
+    { 'a',  '#' }, /* ACS_CKBOARD */
+    { 'u',  '+' }, /* ACS_RTEE */
+    { 't',  '+' }, /* ACS_LTEE */
+    { 'w',  '+' }, /* ACS_TTEE */
+    { 'v',  '+' }, /* ACS_BTEE */
+    { 'n',  '+' }, /* ACS_PLUS */
+    { 0, 0 } };
+
 void init_curses (void)
 {
+    int i;
     initscr();
 #ifdef HAVE_ESCDELAY
     /*
-     * If ncurses exports the ESCDELAY variable it should be set to 0
-     * or you'll have to press Esc three times to dismiss a dialog box.
+     * If ncurses exports the ESCDELAY variable, it should be set to
+     * a low value, or you'll experience a delay in processing escape
+     * sequences that are recognized by mc (e.g. Esc-Esc).  On the other
+     * hand, making ESCDELAY too small can result in some sequences
+     * (e.g. cursor arrows) being reported as separate keys under heavy
+     * processor load, and this can be a problem if mc hasn't learned
+     * them in the "Learn Keys" dialog.  The value is in milliseconds.
      */
-    ESCDELAY = 0;
-#endif
-    if (!status_using_ncurses)
-	do_enter_ca_mode ();
+    ESCDELAY = 200;
+#endif /* HAVE_ESCDELAY */
+    do_enter_ca_mode ();
     mc_raw_mode ();
     noecho ();
     keypad (stdscr, TRUE);
     nodelay (stdscr, FALSE);
     init_colors ();
+    if (force_ugly_line_drawing) {
+	for (i = 0; acs_approx[i].acscode != 0; i++) {
+	    acs_map[acs_approx[i].acscode] = acs_approx[i].character;
+	}
+    }
 }
 #endif /* ! HAVE_SLANG */
 
-void done_screen ()                                                      
-{                                                                               
-    if (!(quit & SUBSHELL_EXIT))                                                
-	clr_scr ();                                                             
-    reset_shell_mode ();                                                        
-    mc_noraw_mode ();                                                           
-    if (use_mouse_p)                                                            
-	shut_mouse ();                                                          
-    keypad (stdscr, FALSE);                                                     
-}                                                                               
+void
+done_screen ()
+{
+    if (!(quit & SUBSHELL_EXIT))
+	clr_scr ();
+    reset_shell_mode ();
+    mc_noraw_mode ();
+    keypad (stdscr, FALSE);
+}
 
 static void
 panel_do_cols (int index)
@@ -624,96 +633,97 @@ panel_do_cols (int index)
     }
 }
 
-void setup_panels (void)
+void
+setup_panels (void)
 {
     int start_y;
     int promptl;		/* the prompt len */
 
-    if (console_flag){
+    if (console_flag) {
 	int minimum;
 	if (output_lines < 0)
 	    output_lines = 0;
-	height = LINES - keybar_visible - command_prompt - menubar_visible
-	         - output_lines - message_visible;
-	if (message_visible && xterm_hintbar && xterm_flag) height++;
+	height =
+	    LINES - keybar_visible - command_prompt - menubar_visible -
+	    output_lines - message_visible;
 	minimum = MINHEIGHT * (1 + horizontal_split);
-	if (height < minimum){
+	if (height < minimum) {
 	    output_lines -= minimum - height;
 	    height = minimum;
 	}
     } else {
-	height = LINES - menubar_visible - command_prompt -
-	    keybar_visible - message_visible;
-	if (message_visible && xterm_hintbar && xterm_flag) height++;
+	height =
+	    LINES - menubar_visible - command_prompt - keybar_visible -
+	    message_visible;
     }
     check_split ();
     start_y = menubar_visible;
 
     /* The column computing is defered until panel_do_cols */
-    if (horizontal_split){
-	widget_set_size (panels [0].widget, start_y, 0, 
-			 first_panel_size, 0);
-			
-	widget_set_size (panels [1].widget, start_y+first_panel_size, 0,
-			 height-first_panel_size, 0);
+    if (horizontal_split) {
+	widget_set_size (panels[0].widget, start_y, 0, first_panel_size,
+			 0);
+
+	widget_set_size (panels[1].widget, start_y + first_panel_size, 0,
+			 height - first_panel_size, 0);
     } else {
 	int first_x = first_panel_size;
 
-	widget_set_size (panels [0].widget, start_y, 0,
-			 height, 0);
+	widget_set_size (panels[0].widget, start_y, 0, height, 0);
+
+	widget_set_size (panels[1].widget, start_y, first_x, height, 0);
 
-	widget_set_size (panels [1].widget, start_y, first_x,
-			 height, 0);
-			
     }
     panel_do_cols (0);
     panel_do_cols (1);
-    
+
     promptl = strlen (prompt);
 
     widget_set_size (&the_menubar->widget, 0, 0, 1, COLS);
 
     if (command_prompt) {
-	    widget_set_size (&cmdline->input.widget,
-			     LINES-1-keybar_visible, promptl,
-			     1, COLS-promptl-(keybar_visible ? 0 : 1));
-	    winput_set_origin (&cmdline->input, promptl, COLS-promptl-(keybar_visible ? 0 : 1));
-	    widget_set_size (&the_prompt->widget,
-			     LINES-1-keybar_visible, 0,
-			     1, promptl);
+	widget_set_size (&cmdline->widget, LINES - 1 - keybar_visible,
+			 promptl, 1,
+			 COLS - promptl - (keybar_visible ? 0 : 1));
+	winput_set_origin (cmdline, promptl,
+			   COLS - promptl - (keybar_visible ? 0 : 1));
+	widget_set_size (&the_prompt->widget, LINES - 1 - keybar_visible,
+			 0, 1, promptl);
     } else {
-	    widget_set_size (&cmdline->input.widget, 0, 0, 0, 0);
-	    winput_set_origin (&cmdline->input, 0, 0);
-	    widget_set_size (&the_prompt->widget, LINES, COLS, 0, 0);
-    }			     
+	widget_set_size (&cmdline->widget, 0, 0, 0, 0);
+	winput_set_origin (cmdline, 0, 0);
+	widget_set_size (&the_prompt->widget, LINES, COLS, 0, 0);
+    }
 
-    widget_set_size (&the_bar->widget, LINES-1, 0, 1, COLS);
+    widget_set_size (&the_bar->widget, LINES - 1, 0, keybar_visible, COLS);
     the_bar->visible = keybar_visible;
-    
+
     /* Output window */
-    if (console_flag && output_lines){
-	output_start_y = LINES -command_prompt-keybar_visible-
-	    output_lines;
+    if (console_flag && output_lines) {
+	output_start_y =
+	    LINES - command_prompt - keybar_visible - output_lines;
 	show_console_contents (output_start_y,
-			       LINES-output_lines-keybar_visible-1,
-			       LINES-keybar_visible-1);
-    } 
-    if (message_visible && (!xterm_hintbar || !xterm_flag))
-	widget_set_size (&the_hint->widget, height+start_y, 0, 1,COLS);
-    else
+			       LINES - output_lines - keybar_visible - 1,
+			       LINES - keybar_visible - 1);
+    }
+    if (message_visible) {
+	widget_set_size (&the_hint->widget, height + start_y, 0, 1, COLS);
+	set_hintbar ("");	/* clean up the line */
+    } else
 	widget_set_size (&the_hint->widget, 0, 0, 0, 0);
-    
-    load_hint ();
+
+    load_hint (1);
+    update_xterm_title_path ();
 }
 
 void flag_winch (int dummy)
 {
+#ifndef USE_NCURSES	/* don't do malloc in a signal handler */
     low_level_change_screen_size ();
+#endif
     winch_flag = 1;
 }
 
-void edit_adjust_size (Dlg_head * h);
-
 static void
 low_level_change_screen_size (void)
 {
@@ -727,7 +737,7 @@ low_level_change_screen_size (void)
     if (winsz.ws_col && winsz.ws_row){
 #if defined(NCURSES_VERSION) && defined(HAVE_RESIZETERM)
 	resizeterm(winsz.ws_row, winsz.ws_col);
-	clearok(stdscr,TRUE);	/* FIXME: sigwinch's should use a semaphore! */
+	clearok(stdscr,TRUE);	/* sigwinch's should use a semaphore! */
 #else
 	COLS = winsz.ws_col;
 	LINES = winsz.ws_row;
@@ -740,11 +750,12 @@ low_level_change_screen_size (void)
 #endif /* defined(HAVE_SLANG) || NCURSES_VERSION_MAJOR >= 4 */
 }
 
-void change_screen_size (void)
+void
+change_screen_size (void)
 {
 #if defined(HAVE_SLANG) || NCURSES_VERSION_MAJOR >= 4
 #if defined TIOCGWINSZ && !defined SCO_FLAVOR
-    
+
 #ifndef NCURSES_VERSION
     mc_noraw_mode ();
     endwin ();
@@ -761,22 +772,20 @@ void change_screen_size (void)
     init_curses ();
 #endif
     setup_panels ();
-    if (current_dlg == view_dlg)
-	view_adjust_size (view_dlg);
-#ifdef USE_INTERNAL_EDIT
-    if (current_dlg == edit_dlg)
-	edit_adjust_size (edit_dlg);
-#endif
-    
+
+    /* Inform currently running dialog */
+    (*current_dlg->callback) (current_dlg, current_dlg->current->dlg_id,
+			      DLG_RESIZE);
+
 #ifdef RESIZABLE_MENUBAR
-	menubar_arrange(the_menubar);
+    menubar_arrange (the_menubar);
 #endif
-		
+
     /* Now, force the redraw */
     do_refresh ();
     touchwin (stdscr);
-#endif /* TIOCGWINSZ && !SCO_FLAVOR */
-#endif /* defined(HAVE_SLANG) || NCURSES_VERSION_MAJOR >= 4 */
+#endif				/* TIOCGWINSZ && !SCO_FLAVOR */
+#endif				/* defined(HAVE_SLANG) || NCURSES_VERSION_MAJOR >= 4 */
     winch_flag = 0;
 }
 
@@ -792,14 +801,9 @@ void use_dash (int flag)
 
 void set_hintbar(char *str) 
 {
-    if (xterm_flag && xterm_hintbar) {
-	fprintf (stdout, "\33]0;mc - %s\7", str);
-	fflush (stdout);
-    } else {
-        label_set_text (the_hint, str);
-        if (ok_to_refresh > 0)
-	    refresh();
-    }
+    label_set_text (the_hint, str);
+    if (ok_to_refresh > 0)
+        refresh();
 }
 
 void print_vfs_message (char *msg, ...)
@@ -816,16 +820,25 @@ void print_vfs_message (char *msg, ...)
 	return;
 
     if (!message_visible || !the_hint || !the_hint->widget.parent) {
+	int col, row;
 
 	if (!nice_rotating_dash || (ok_to_refresh <= 0))
 	    return;
+
+	/* Preserve current cursor position */
+	getyx (stdscr, row, col);
+
 	move (0, 0);
+	attrset (NORMAL_COLOR);
 	printw ("%-*s", COLS-1, str);
+
+	/* Restore cursor position */
+	move(row, col);
 	mc_refresh ();
 	return;
     }
 
-    if (message_visible || (xterm_flag && xterm_hintbar)) {
+    if (message_visible) {
         set_hintbar(str);
     }
 }
@@ -899,7 +912,7 @@ void set_display_type (int num, int type)
     x = y = cols = lines = 0;
     old_widget = 0;
     if (num >= MAX_VIEWS){
-	fprintf (stderr, "Could not allocate more that %d views\n", MAX_VIEWS);
+	fprintf (stderr, "Cannot allocate more that %d views\n", MAX_VIEWS);
 	abort ();
     }
 
@@ -967,14 +980,6 @@ void set_display_type (int num, int type)
     /* We set the same size the old widget had */
     widget_set_size ((Widget *) new_widget, y, x, lines, cols);
     
-    /* We wanna the new widget at the same position */
-    /* XView sets wcontainer to !0 <- Not XView, but we, when we create it */
-    /* Ok, the XView support code does it */
-    if (old_widget && old_widget->wcontainer){
-	new_widget->wcontainer = old_widget->wcontainer;
-	new_widget->area = old_widget->area;
-    }
-
     /* We use replace to keep the circular list of the dialog in the */
     /* same state.  Maybe we could just kill it and then replace it  */
     if (midnight_dlg && old_widget){
