@@ -21,27 +21,12 @@
 
 #include <sys/types.h>
 #include <stdio.h>
-#include <fcntl.h>
-
-#ifdef STDC_HEADERS
-#include <stdlib.h>
-#else
-void free (void *ptr);
-#endif
-#if defined(STDC_HEADERS) || defined(HAVE_STRING_H)
-#include <string.h>
-#else
-#include <strings.h>
-#endif
 
+/* This header needs to be included before sys/mount.h on *BSD */
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
 
-#ifdef HAVE_UNISTD_H
-#    include <unistd.h>
-#endif
-
 #if defined (MOUNTED_GETFSSTAT)	/* __alpha running OSF_1 */
 #include <sys/mount.h>
 #include <sys/fs_types.h>
@@ -96,6 +81,7 @@ void free (void *ptr);
 #include <sys/fsys.h>
 #endif
 
+#include "global.h"
 #include "mountlist.h"
 #include "fsusage.h"
 #include "util.h"
@@ -108,6 +94,16 @@ void free (void *ptr);
 #define MOUNTED_GETMNTTBL
 #endif
 
+/* A mount table entry. */
+struct mount_entry
+{
+  char *me_devname;		/* Device node pathname, including "/dev/". */
+  char *me_mountdir;		/* Mount point directory pathname. */
+  char *me_type;		/* "nfs", "4.2", etc. */
+  dev_t me_dev;			/* Device number of me_mountdir. */
+  struct mount_entry *me_next;
+};
+
 #ifdef HAVE_INFOMOUNT_LIST
 
 static struct mount_entry *mount_list = NULL;
@@ -172,7 +168,8 @@ static char *fstype_to_string (short t)
 #endif /* MOUNTED_GETMNTINFO && !HAVE_F_FSTYPENAME */
 
 #ifdef MOUNTED_VMOUNT		/* AIX.  */
-static char *fstype_to_string (int t)
+static char *
+fstype_to_string (int t)
 {
     struct vfs_ent *e;
 
@@ -191,7 +188,8 @@ static char *fstype_to_string (int t)
    If ALL_FS is zero, do not return entries for filesystems that
    are automounter (dummy) entries.  */
 
-struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
+static struct mount_entry *
+read_filesystem_list (int need_fs_type, int all_fs)
 {
     struct mount_entry *mlist;
     struct mount_entry *me;
@@ -203,13 +201,13 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
     mlist = mtail = me;
 
 #ifdef MOUNTED_GETMNTENT1	/* 4.3BSD, SunOS, HP-UX, Dynix, Irix.  */
+#ifdef MOUNTED
     {
 	struct mntent *mnt;
-	char *table = MOUNTED;
 	FILE *fp;
 	char *devopt;
 
-	fp = setmntent (table, "r");
+	fp = setmntent (MOUNTED, "r");
 	if (fp == NULL)
 	    return NULL;
 
@@ -240,6 +238,7 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 	if (endmntent (fp) == 0)
 	    return NULL;
     }
+#endif /* MOUNTED */
 #endif /* MOUNTED_GETMNTENT1 */
 
 #ifdef MOUNTED_GETMNTINFO	/* 4.4BSD.  */
@@ -482,7 +481,8 @@ struct mount_entry *read_filesystem_list (int need_fs_type, int all_fs)
 ** this hack.
 */
 
-struct mount_entry *read_filesystem_list(int need_fs_type, int all_fs)
+static struct mount_entry *
+read_filesystem_list(int need_fs_type, int all_fs)
 {
 	struct _disk_entry	de;
 	struct statfs		fs;
@@ -542,14 +542,16 @@ struct mount_entry *read_filesystem_list(int need_fs_type, int all_fs)
 }
 #endif /* HAVE_INFOMOUNT_QNX */
 
-void init_my_statfs (void)
+void
+init_my_statfs (void)
 {
 #ifdef HAVE_INFOMOUNT_LIST
     mount_list = read_filesystem_list (1, 1);
 #endif /* HAVE_INFOMOUNT_LIST */
 }
 
-void my_statfs (struct my_statfs *myfs_stats, char *path)
+void
+my_statfs (struct my_statfs *myfs_stats, char *path)
 {
 #ifdef HAVE_INFOMOUNT_LIST
     int i, len = 0;
