@@ -9,12 +9,13 @@
 #include "poptalloca.h"
 #include <errno.h>
 #include <ctype.h>
-#include <fcntl.h>
 #include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
 
 #include "findme.h"
 #include "popt.h"
@@ -191,6 +192,7 @@ static int handleAlias(poptContext con, char * longName, char shortName,
 }
 
 static void execCommand(poptContext con) {
+#if 0
     char ** argv;
     int pos = 0;
     char * script = con->doExec->script;
@@ -223,24 +225,10 @@ static void execCommand(poptContext con) {
 
     argv[pos++] = NULL;
 
-#ifdef __hpux
-    setresuid(getuid(), getuid(),-1);
-#else
-/*
- * XXX " ... on BSD systems setuid() should be preferred over setreuid()"
- * XXX 	sez' Timur Bakeyev <mc@bat.ru>
- * XXX	from Norbert Warmuth <nwarmuth@privat.circular.de>
- */
-#if defined(HAVE_SETUID)
-    setuid(getuid());
-#elif defined (HAVE_SETREUID)
-    setreuid(getuid(), getuid()); /*hlauer: not portable to hpux9.01 */
-#else
-    ; /* Cannot drop privileges */
-#endif
-#endif
-
     execvp(argv[0], argv);
+#else
+    abort();
+#endif
 }
 
 static const struct poptOption * findOption(const struct poptOption * table,
@@ -556,15 +544,15 @@ char * poptBadOption(poptContext con, int flags) {
 const char * poptStrerror(const int error) {
     switch (error) {
       case POPT_ERROR_NOARG:
-	return POPT_("missing argument");
+	return _("missing argument");
       case POPT_ERROR_BADOPT:
-	return POPT_("unknown option");
+	return _("unknown option");
       case POPT_ERROR_OPTSTOODEEP:
 	return POPT_("aliases nested too deeply");
       case POPT_ERROR_BADQUOTE:
-	return POPT_("error in paramter quoting");
+	return POPT_("error in parameter quoting");
       case POPT_ERROR_BADNUMBER:
-	return POPT_("invalid numeric value");
+	return _("invalid numeric value");
       case POPT_ERROR_OVERFLOW:
 	return POPT_("number too large or too small");
       case POPT_ERROR_ERRNO:
