@@ -18,15 +18,15 @@
 #include <config.h>
 #include <sys/types.h>		/* Needed to include local .h files */
 #include <sys/stat.h>
-#include <sys/param.h>
 #include <string.h>
-#include "tty.h"
 #include <stdio.h>
+
 #include "global.h"
+#include "tty.h"
 #include "dir.h"
 #include "panel.h"
 #include "main.h"
-#include "tree.h"
+#include "tree.h"		/* xtree_mode */
 #include "profile.h"
 #define WANT_WIDGETS
 #include "setup.h"
@@ -39,48 +39,27 @@
 #include "menu.h"		/* menubar_visible declaration */
 #include "win.h"		/* lookup_key */
 #include "cmd.h"
-#include "file.h"
-#include "x.h"
-
-#ifdef HAVE_GNOME
-#    include "gdesktop.h"
-#endif
-
-#ifndef PORT_LIST_MODE_NAME
-#     define PORT_LIST_MODE_NAME "list_mode"
-#endif
-
-#ifndef PORT_LIST_MODE_DEFAULT
-#     define PORT_LIST_MODE_DEFAULT "full"
-#endif
+#include "file.h"		/* safe_delete */
 
 #ifdef HAVE_CHARSET
 #include "charsets.h"
 #endif
 
-#include "../vfs/vfs.h"
 #ifdef USE_NETCODE
 #   include "../vfs/ftpfs.h"
 #endif
 
-#ifdef HAVE_GNOME
-extern int tree_panel_visible;
-extern int we_can_afford_the_speed;
-int use_magic = 0;
+#ifdef USE_INTERNAL_EDIT
+#   include "../edit/edit.h"
 #endif
 
-/* "$Id: setup.c,v 1.52 2001/08/16 21:01:12 proskin Exp $" */
-
-#ifdef USE_VFS
-extern int vfs_timeout;
-extern int tar_gzipped_memlimit;
-#endif
 
 extern char *find_ignore_dirs;
 
 extern int num_history_items_recorded;
 
-char *profile_name;
+char *profile_name;		/* .mc/ini */
+char *global_profile_name;	/* mc.lib */
 
 char setup_color_string [4096];
 char term_color_string [4096];
@@ -120,7 +99,6 @@ static const struct {
     { "brief", list_brief },
     { "long",  list_long  },
     { "user",  list_user  },
-    { "icons", list_icons },
     { 0, 0 }
 };
 
@@ -135,7 +113,6 @@ static const struct {
     { 0, 0 }
 };
 
-#ifndef HAVE_GNOME
 static const struct {
     char *opt_name;
     int *opt_addr;
@@ -144,7 +121,7 @@ static const struct {
     { "first_panel_size", &first_panel_size },
     { "message_visible", &message_visible },
     { "keybar_visible", &keybar_visible },
-    { "xterm_hintbar", &xterm_hintbar },
+    { "xterm_title", &xterm_title },
     { "output_lines", &output_lines },
     { "command_prompt", &command_prompt },
     { "menubar_visible", &menubar_visible },
@@ -153,31 +130,18 @@ static const struct {
     { "filetype_mode", &filetype_mode },
     { 0, 0 }
 };
-#endif
-
-
-#undef SAVE_CHANGES_OUTSIDE_OPTIONS_MENU
-
-#ifdef SAVE_CHANGES_OUTSIDE_OPTIONS_MENU
-extern int preserve_uidgid;
-#endif
 
 static const struct {
     char *opt_name;
     int  *opt_addr;
 } options [] = {
     { "show_backups", &show_backups },
-#ifdef HAVE_GNOME
-    { "gnome_show_dot_files", &show_dot_files },
-#else
     { "show_dot_files", &show_dot_files },
-#endif
     { "verbose", &verbose },
     { "mark_moves_down", &mark_moves_down },
     { "pause_after_run", &pause_after_run },
     { "shell_patterns", &easy_patterns },
     { "auto_save_setup", &auto_save_setup },
-    { "align_extensions", &align_extensions },
     { "auto_menu", &auto_menu },
     { "use_internal_view", &use_internal_view },
     { "use_internal_edit", &use_internal_edit },
@@ -189,33 +153,26 @@ static const struct {
     { "confirm_overwrite", &confirm_overwrite },
     { "confirm_execute", &confirm_execute },
     { "confirm_exit", &confirm_exit },
-    { "safe_delete", &know_not_what_am_i_doing },
-#ifndef HAVE_X
+    { "safe_delete", &safe_delete },
     { "mouse_repeat_rate", &mou_auto_repeat },
     { "double_click_speed", &double_click_speed },
 #ifndef HAVE_CHARSET
     { "eight_bit_clean", &eight_bit_clean },
     { "full_eight_bits", &full_eight_bits },
-#endif
+#endif /* !HAVE_CHARSET */
     { "use_8th_bit_as_meta", &use_8th_bit_as_meta },
-#endif
     { "confirm_view_dir", &confirm_view_dir },
     { "mouse_move_pages", &mouse_move_pages },
     { "mouse_move_pages_viewer", &mouse_move_pages_viewer },
     { "fast_refresh", &fast_refresh },
     { "navigate_with_arrows", &navigate_with_arrows },
-    { "advanced_chown", &advanced_chfns },
     { "drop_menus", &drop_menus },
     { "wrap_mode",  &global_wrap_mode},
-#ifndef HAVE_X
     { "old_esc_mode", &old_esc_mode },
     { "cd_symlinks", &cd_symlinks },
-#endif
     { "show_all_if_ambiguous", &show_all_if_ambiguous },
     { "have_fast_cpu", &have_fast_cpu },
-#if 0
-    { "iconify_on_exec", &iconify_on_exec },
-#endif
+    { "max_dirt_limit", &max_dirt_limit },
     { "torben_fj_mode", &torben_fj_mode },
     { "use_file_to_guess_type", &use_file_to_check_type },
     { "alternate_plus_minus", &alternate_plus_minus },
@@ -225,16 +182,6 @@ static const struct {
     { "xtree_mode", &xtree_mode },
     { "num_history_items_recorded", &num_history_items_recorded },
     { "file_op_compute_totals", &file_op_compute_totals },
-#ifdef HAVE_GNOME
-    { "use_magic", &use_magic },
-#endif
-#ifdef SAVE_CHANGES_OUTSIDE_OPTIONS_MENU
-    { "dive_into_subdirs", &dive_into_subdirs },
-    { "preserve_uidgid", &preserve_uidgid },
-    /* What about the other two options in the copy dialog
-       (follow links, stable symlinks) -Norbert */
-    { "tree_navigation_flag", &tree_navigation_flag },
-#endif
 #ifdef USE_VFS
     { "vfs_timeout", &vfs_timeout },
 #ifdef USE_NETCODE
@@ -245,8 +192,8 @@ static const struct {
     { "ftpfs_use_passive_connections", &ftpfs_use_passive_connections },
     { "ftpfs_use_unix_list_options", &ftpfs_use_unix_list_options },
     { "ftpfs_first_cd_then_ls", &ftpfs_first_cd_then_ls },
-#endif
-#endif
+#endif /* USE_NETCODE */
+#endif /* USE_VFS */
 #ifdef USE_INTERNAL_EDIT
     { "editor_word_wrap_line_length", &option_word_wrap_line_length },
     { "editor_key_emulation", &edit_key_emulation },
@@ -256,55 +203,21 @@ static const struct {
     { "editor_backspace_through_tabs", &option_backspace_through_tabs },
     { "editor_fake_half_tabs", &option_fake_half_tabs },
     { "editor_option_save_mode", &option_save_mode },
+    { "editor_option_save_position", &option_save_position },
     { "editor_option_backup_ext_int", &option_backup_ext_int },
     { "editor_option_auto_para_formatting", &option_auto_para_formatting },
     { "editor_option_typewriter_wrap", &option_typewriter_wrap },
     { "editor_edit_confirm_save", &edit_confirm_save },
     { "editor_syntax_highlighting", &option_syntax_highlighting },
-#endif
+#endif /* USE_INTERNAL_EDIT */
 
-#ifdef HAVE_GNOME
-    { "desktop_use_shaped_icons", &desktop_use_shaped_icons },
-    { "desktop_use_shaped_text", &desktop_use_shaped_text },
-    { "desktop_auto_placement", &desktop_auto_placement },
-    { "desktop_snap_icons", &desktop_snap_icons },
-    { "desktop_arr_r2l", &desktop_arr_r2l },
-    { "desktop_arr_b2t", &desktop_arr_b2t },
-    { "desktop_arr_rows", &desktop_arr_rows },
-    { "tree_panel_visible", &tree_panel_visible },
-    { "we_can_afford_the_speed", &we_can_afford_the_speed },
-
-    /* Keep the following in sync with panel.h */
-    { "column_width_brief_icon", &default_column_width[0] },
-    { "column_width_brief_filename", &default_column_width[1] },
-    { "column_width_detailed_icon", &default_column_width[2] },
-    { "column_width_detailed_filename", &default_column_width[3] },
-    { "column_width_detailed_size", &default_column_width[4] },
-    { "column_width_detailed_mtime", &default_column_width[5] },
-    { "column_width_custom_0", &default_column_width[6] },
-    { "column_width_custom_1", &default_column_width[7] },
-    { "column_width_custom_2", &default_column_width[8] },
-    { "column_width_custom_3", &default_column_width[9] },
-    { "column_width_custom_4", &default_column_width[10] },
-    { "column_width_custom_5", &default_column_width[11] },
-    { "column_width_custom_6", &default_column_width[12] },
-    { "column_width_custom_7", &default_column_width[13] },
-    { "column_width_custom_8", &default_column_width[14] },
-    { "column_width_custom_9", &default_column_width[15] },
-    { "column_width_custom_10", &default_column_width[16] },
-    { "column_width_custom_11", &default_column_width[17] },
-    { "column_width_custom_12", &default_column_width[18] },
-    { "column_width_custom_13", &default_column_width[19] },
-    { "column_width_custom_14", &default_column_width[20] },
-#else
     { "nice_rotating_dash", &nice_rotating_dash },
     { "horizontal_split",   &horizontal_split },
-#endif
     { 0, 0 }
 };
 
 void
-panel_save_setup (WPanel *panel, char *section)
+panel_save_setup (struct WPanel *panel, char *section)
 {
     char buffer [BUF_TINY];
     int  i;
@@ -322,7 +235,7 @@ panel_save_setup (WPanel *panel, char *section)
 
     for (i = 0; list_types [i].key; i++)
 	if (list_types [i].list_type == panel->list_type){
-	    save_string (section, PORT_LIST_MODE_NAME, list_types [i].key, profile_name);
+	    save_string (section, "list_mode", list_types [i].key, profile_name);
 	    break;
 	}
 
@@ -340,7 +253,6 @@ panel_save_setup (WPanel *panel, char *section)
 			       profile_name);
 }
 
-#ifndef HAVE_X
 void
 save_layout (void)
 {
@@ -358,7 +270,6 @@ save_layout (void)
 
     g_free (profile);
 }
-#endif /* !HAVE_X */
 
 void
 save_configure (void)
@@ -372,14 +283,9 @@ save_configure (void)
     for (i = 0; options [i].opt_name; i++)
 	set_int (profile, options [i].opt_name, *options [i].opt_addr);
 
-#ifdef HAVE_GNOME
-    save_string (app_text, "default_user_format", default_user_format, profile_name);
-#endif
-
     g_free (profile);
 }
 
-#ifndef PORT_HAS_SAVE_PANEL_TYPES
 static void
 panel_save_type (char *section, int type)
 {
@@ -394,7 +300,7 @@ panel_save_type (char *section, int type)
 }
 
 void
-save_panel_types ()
+save_panel_types (void)
 {
     int type;
 
@@ -407,7 +313,6 @@ save_panel_types ()
     if (type == view_listing)
 	panel_save_setup (right_panel, right_panel->panel_name);
 }
-#endif
 
 void
 save_setup (void)
@@ -419,7 +324,6 @@ save_setup (void)
 
     save_configure ();
 
-#ifndef HAVE_X
     save_layout ();
     save_string ("Dirs", "other_dir",
 			       get_other_type () == view_listing
@@ -428,26 +332,23 @@ save_setup (void)
 	    WritePrivateProfileString ("Dirs", "current_is_left",
 				       get_current_index () == 0 ? "1" : "0", profile);
     save_hotlist ();
-#endif /* !HAVE_X */
 
     save_panelize ();
     save_panel_types ();
 /*     directory_history_save (); */
 
-#ifdef USE_VFS
-#ifdef USE_NETCODE
+#if defined(USE_VFS) && defined (USE_NETCODE)
     WritePrivateProfileString ("Misc", "ftpfs_password",
 			       ftpfs_anonymous_passwd, profile);
     if (ftpfs_proxy_host)
 	WritePrivateProfileString ("Misc", "ftp_proxy_host",
 				   ftpfs_proxy_host, profile);
-#endif
-#endif
+#endif /* USE_VFS && USE_NETCODE */
 
 #ifdef HAVE_CHARSET
     save_string( "Misc", "display_codepage",
     		 get_codepage_id( display_codepage ), profile_name );
-#endif
+#endif /* HAVE_CHARSET */
 
     g_free (profile);
     saving_setup = 0;
@@ -472,17 +373,14 @@ panel_load_setup (WPanel *panel, char *section)
 	}
 
     /* Load the listing mode */
-    load_string (section, PORT_LIST_MODE_NAME, PORT_LIST_MODE_DEFAULT, buffer, sizeof (buffer));
+    load_string (section, "list_mode", "full", buffer, sizeof (buffer));
     panel->list_type = list_full;
     for (i = 0; list_types [i].key; i++)
 	if ( g_strcasecmp (list_types [i].key, buffer) == 0){
 	    panel->list_type = list_types [i].list_type;
 	    break;
 	}
-#ifndef PORT_HAS_ICON_VIEW
-    if (panel->list_type == list_icons)
-        panel->list_type = list_full;
-#endif
+
     /* User formats */
     if (panel->user_format){
 	g_free (panel->user_format);
@@ -505,7 +403,6 @@ panel_load_setup (WPanel *panel, char *section)
 
 }
 
-#ifndef HAVE_X
 static void
 load_layout (char *profile_name)
 {
@@ -516,7 +413,6 @@ load_layout (char *profile_name)
 	    load_int ("Layout", layout [i].opt_name,
 				  *layout [i].opt_addr);
 }
-#endif /* !HAVE_X */
 
 static int
 load_mode (char *section)
@@ -538,6 +434,7 @@ load_mode (char *section)
     return mode;
 }
 
+#ifdef USE_NETCODE
 static char *
 do_load_string (char *s, char *ss, char *def)
 {
@@ -550,6 +447,7 @@ do_load_string (char *s, char *ss, char *def)
     g_free (buffer);
     return p;
 }
+#endif /* !USE_NETCODE */
 
 char *
 setup_init (void)
@@ -582,17 +480,17 @@ load_setup (void)
     int    i;
 
     profile = setup_init ();
+
+    /* mc.lib is common for all users, but has priority lower than
+       ~/.mc/ini.  FIXME: it's only used for keys and treestore now */
+    global_profile_name = concat_dir_and_file (mc_home, "mc.lib");
+
     /* Load integer boolean options */
     for (i = 0; options [i].opt_name; i++)
 	*options [i].opt_addr =
 	    get_int (profile, options [i].opt_name, *options [i].opt_addr);
 
-#ifdef HAVE_X
-    g_free (default_user_format);
-    default_user_format = do_load_string (app_text, "default_user_format", DEFAULT_USER_FORMAT);
-#else
     load_layout (profile);
-#endif
 
     load_panelize ();
 
@@ -603,7 +501,6 @@ load_setup (void)
     if (startup_left_mode != view_listing && startup_right_mode!=view_listing)
 	startup_left_mode = view_listing;
 
-#ifndef HAVE_X
     if (!other_dir){
 	char *buffer;
 
@@ -618,7 +515,6 @@ load_setup (void)
 
     boot_current_is_left =
 	GetPrivateProfileInt ("Dirs", "current_is_left", 1, profile);
-#endif /* !HAVE_X */
 
 #ifdef USE_NETCODE
     ftpfs_proxy_host = do_load_string ("Misc", "ftp_proxy_host", "gate");
@@ -642,11 +538,9 @@ load_setup (void)
     /* Remove the temporal entries */
     profile_clean_section ("Temporal:New Left Panel", profile_name);
     profile_clean_section ("Temporal:New Right Panel", profile_name);
-#ifdef USE_VFS
-#ifdef USE_NETCODE
+#if defined(USE_VFS) && defined (USE_NETCODE)
     ftpfs_init_passwd ();
-#endif
-#endif
+#endif /* USE_VFS && USE_NETCODE */
 
 #ifdef HAVE_CHARSET
     if ( load_codepages_list() > 0 ) {
@@ -657,13 +551,11 @@ load_setup (void)
 	    display_codepage = get_codepage_index( cpname );
     }
 
-    init_printable_table( display_codepage );
     init_translation_table( source_codepage, display_codepage );
-#endif
+#endif /* HAVE_CHARSET */
 }
 
-#ifdef USE_VFS
-#ifdef USE_NETCODE
+#if defined(USE_VFS) && defined (USE_NETCODE)
 char *
 load_anon_passwd ()
 {
@@ -675,20 +567,17 @@ load_anon_passwd ()
     else
 	return 0;
 }
-#endif
-#endif
+#endif /* USE_VFS && USE_NETCODE */
 
 void done_setup (void)
 {
     g_free (profile_name);
-#ifndef HAVE_X
+    g_free (global_profile_name);
     done_hotlist ();
-#endif /* HAVE_X */
     done_panelize ();
 /*    directory_history_free (); */
 }
 
-#ifndef HAVE_X
 static void
 load_keys_from_section (char *terminal, char *profile_name)
 {
@@ -702,11 +591,7 @@ load_keys_from_section (char *terminal, char *profile_name)
 
     section_name = g_strconcat ("terminal:", terminal, NULL);
     profile_keys = profile_init_iterator (section_name, profile_name);
-    if (!profile_keys){
-	g_free (section_name);
-	return;
-    }
-
+    g_free (section_name);
     while (profile_keys){
 	profile_keys = profile_iterator_next (profile_keys, &key, &value);
 	key_code = lookup_key (key);
@@ -716,25 +601,19 @@ load_keys_from_section (char *terminal, char *profile_name)
 	    g_free (valcopy);
 	}
     }
-    g_free (section_name);
-    return;
 }
 
 void load_key_defs (void)
 {
-    char *libfile = concat_dir_and_file (mc_home, "mc.lib");
-
     /*
      * Load keys from mc.lib before ~/.mc/ini, so that the user
      * definitions override global settings.
      */
-    load_keys_from_section ("general", libfile);
-    load_keys_from_section (getenv ("TERM"), libfile);
+    load_keys_from_section ("general", global_profile_name);
+    load_keys_from_section (getenv ("TERM"), global_profile_name);
     load_keys_from_section ("general", profile_name);
     load_keys_from_section (getenv ("TERM"), profile_name);
 
     /* We don't want a huge database loaded in core */
-    free_profile_name (libfile);
-    g_free (libfile);
+    free_profile_name (global_profile_name);
 }
-#endif
