@@ -17,16 +17,12 @@
 
 #include <config.h>
 #include <stdio.h>
-#ifdef NEEDS_IO_H
-#    include <io.h>
-#endif
-#include "tty.h"
 #include <string.h>
 #include <ctype.h>
 #include <errno.h>
-#include <fcntl.h>
+
 #include "global.h"
-#include "x.h"
+#include "tty.h"
 #include "dialog.h"
 #include "color.h"
 #include "dir.h"
@@ -36,6 +32,9 @@
 #include "user.h"
 #include "layout.h"
 #include "setup.h"
+
+#include "edit/edit.h"		/* BLOCK_FILE */
+#include "edit/edit-widget.h"	/* WEdit */
 #include "../vfs/vfs.h"
 
 /* For the simple listbox manager */
@@ -45,15 +44,11 @@
 
 #include "view.h" /* for default_* externs */
 
-/* "$Id: user.c,v 1.29 2001/08/14 00:55:38 proskin Exp $" */
-
 #define MAX_ENTRIES 16
 #define MAX_ENTRY_LEN 60
 
-#ifndef HAVE_X
 static int debug_flag = 0;
 static int debug_error = 0;
-#endif /* !HAVE_X */
 static char *menu = NULL;
 
 /* Formats defined:
@@ -177,16 +172,17 @@ strip_ext(char *ss)
     return ss;
 }
 
-char *expand_format (WEdit *edit_widget, char c, int quote)
+char *
+expand_format (struct WEdit *edit_widget, char c, int quote)
 {
     WPanel *panel;
-    char *(*quote_func)(const char *, int);
+    char *(*quote_func) (const char *, int);
     char *fname;
 
     if (c == '%')
 	return g_strdup ("%");
-    
-    if (islower (c))
+
+    if (islower ((unsigned) c))
 	panel = cpanel;
     else {
 	if (get_other_type () != view_listing)
@@ -202,89 +198,103 @@ char *expand_format (WEdit *edit_widget, char c, int quote)
 	quote_func = fake_name_quote;
 
     c = tolower (c);
-    fname = panel->dir.list [panel->selected].fname;
-    
-    switch (c){
-    case 'f': 
-    case 'p': return (*quote_func) (fname, 0);
-    case 'x': return (*quote_func) (extension(fname), 0);
-    case 'd': return (*quote_func) (panel->cwd, 0);
-    case 'i': /* indent equal number cursor position in line */
-        if (edit_widget)
-	        return g_strnfill (edit_widget->curs_col, ' ');
-        break;
-    case 'y': /* syntax type */
-        if (edit_widget && edit_widget->syntax_type)
-	        return g_strdup (edit_widget->syntax_type);
-        break;
-    case 'e': /* error file name */
-    case 'b': /* block file name / strip extension */ {
-	if (edit_widget) {
-	    char *file = g_strconcat (home_dir,
-				      (c == 'e') ? ERROR_FILE : BLOCK_FILE,
-				      NULL);
-	    fname = (*quote_func) (file, 0);
-	    g_free (file);
-	    return fname;
-	} else if (c == 'e') {
-	    return strip_ext((*quote_func) (fname, 0));
-	}
-    }
-    case 'n': /* strip extension in editor */
+    fname = panel->dir.list[panel->selected].fname;
+
+    switch (c) {
+    case 'f':
+    case 'p':
+	return (*quote_func) (fname, 0);
+    case 'x':
+	return (*quote_func) (extension (fname), 0);
+    case 'd':
+	return (*quote_func) (panel->cwd, 0);
+    case 'i':			/* indent equal number cursor position in line */
 	if (edit_widget)
-	    return strip_ext((*quote_func) (fname, 0));
+	    return g_strnfill (edit_widget->curs_col, ' ');
 	break;
-    case 'm': /* menu file name */
+    case 'y':			/* syntax type */
+	if (edit_widget && edit_widget->syntax_type)
+	    return g_strdup (edit_widget->syntax_type);
+	break;
+    case 'k':			/* block file name */
+    case 'b':			/* block file name / strip extension */  {
+	    if (edit_widget) {
+		char *file = g_strconcat (home_dir, BLOCK_FILE, NULL);
+		fname = (*quote_func) (file, 0);
+		g_free (file);
+		return fname;
+	    } else if (c == 'b') {
+		return strip_ext ((*quote_func) (fname, 0));
+	    }
+	    break;
+	}
+    case 'n':			/* strip extension in editor */
+	if (edit_widget)
+	    return strip_ext ((*quote_func) (fname, 0));
+	break;
+    case 'm':			/* menu file name */
 	if (menu)
 	    return (*quote_func) (menu, 0);
 	break;
-    case 's': if (!panel->marked)
-		return (*quote_func) (fname, 0);
+    case 's':
+	if (!panel->marked)
+	    return (*quote_func) (fname, 0);
 
 	/* Fall through */
 
     case 't':
     case 'u':
-    {
-	int length = 2, i;
-	char *block, *tmp;
-	
-	for (i = 0; i < panel->count; i++)
-	    if (panel->dir.list [i].f.marked)
-		length += strlen (panel->dir.list [i].fname) + 1; /* for space */
+	{
+	    int length = 2, i;
+	    char *block, *tmp;
 
-	block = g_malloc (length*2+1);
-	*block = 0;
-	for (i = 0; i < panel->count; i++)
-	    if (panel->dir.list [i].f.marked){
-		strcat (block, tmp = (*quote_func) (panel->dir.list [i].fname, 0));
-		g_free (tmp);
-		strcat (block, " ");
-		if (c == 'u')
-		    do_file_mark (panel, i, 0);
-	    }
-	return block;
-    } /* sub case block */
-    } /* switch */
+	    for (i = 0; i < panel->count; i++)
+		if (panel->dir.list[i].f.marked)
+		    length += strlen (panel->dir.list[i].fname) + 1;	/* for space */
+
+	    block = g_malloc (length * 2 + 1);
+	    *block = 0;
+	    for (i = 0; i < panel->count; i++)
+		if (panel->dir.list[i].f.marked) {
+		    strcat (block, tmp =
+			    (*quote_func) (panel->dir.list[i].fname, 0));
+		    g_free (tmp);
+		    strcat (block, " ");
+		    if (c == 'u')
+			do_file_mark (panel, i, 0);
+		}
+	    return block;
+	}			/* sub case block */
+    }				/* switch */
     return g_strdup ("");
 }
 
-#ifndef HAVE_X
-/* Checks for shell patterns definition */
-char *check_patterns (char *p)
+/*
+ * Check for the "shell_patterns" directive.  If it's found and valid,
+ * interpret it and move the pointer past the directive.  Return the
+ * current pointer.
+ */
+static char *
+check_patterns (char *p)
 {
-    static const char def_name [] = "shell_patterns=";
-    int value;
+    static const char def_name[] = "shell_patterns=";
+    char *p0 = p;
 
-    if (strncmp (p, def_name, sizeof (def_name) - 1) == 0){
-	p += sizeof (def_name) - 1;
-	value = *p++ - '0';
-	if (value == 0 || value == 1)
-	    easy_patterns = value;
-	else
-	    message (1, MSG_ERROR, _(" Invalid shell pattern definition \"%c\". "), value + '0');
-    }
-    while (*p == '\n' || *p == '\t' || *p == ' ') p++;
+    if (strncmp (p, def_name, sizeof (def_name) - 1) != 0)
+	return p0;
+
+    p += sizeof (def_name) - 1;
+    if (*p == '1')
+	easy_patterns = 1;
+    else if (*p == '0')
+	easy_patterns = 0;
+    else
+	return p0;
+
+    /* Skip spaces */
+    p++;
+    while (*p == '\n' || *p == '\t' || *p == ' ')
+	p++;
     return p;
 }
 
@@ -435,7 +445,7 @@ debug_out (char *start, char *end, int cond)
 	    len = strlen (msg);
 	    if (len)
 		msg [len - 1] = 0;
-	    message (0, _(" Debug "), msg);
+	    message (0, _(" Debug "), "%s", msg);
 	    debug_flag = 0;
 	}
     } else {
@@ -543,7 +553,7 @@ execute_menu_command (WEdit *edit_widget, char *commands)
     char prompt [80];
     int  col;
     char *file_name;
-#ifdef OS2_NT
+#ifdef NATIVE_WIN32
     char *p;
 #endif
     /* Skip menu entry title line */
@@ -598,9 +608,9 @@ execute_menu_command (WEdit *edit_widget, char *commands)
 	    }
 	} else if (expand_prefix_found){
 	    expand_prefix_found = 0;
-	    if (isdigit (*commands)) {
+	    if (isdigit ((unsigned)*commands)) {
 		do_quote = atoi (commands);
-		while (isdigit (*commands))
+		while (isdigit ((unsigned)*commands))
 		    commands++;
 	    }
 	    if (*commands == '{')
@@ -655,10 +665,11 @@ menu_file_own(char* path)
 }
 
 /*
-    if edit_widget = pointer then it is file menu from cool edit
-    if edit_widget = NULL then routine is invoke from file menu of mc.
-*/
-void user_menu_cmd (WEdit *edit_widget)
+ * If edit_widget is NULL then we are called from the mc menu,
+ * otherwise we are called from the mcedit menu.
+ */
+void
+user_menu_cmd (struct WEdit *edit_widget)
 {
     char *p;
     char *data, **entries;
@@ -668,8 +679,8 @@ void user_menu_cmd (WEdit *edit_widget)
     Listbox *listbox;
     
     if (!vfs_current_is_local ()){
-	message (1, _(" Oops... "),
-		 _(" I can't run programs while logged on a non local directory "));
+	message (1, MSG_ERROR,
+		 _(" Cannot execute commands on non-local filesystems"));
 	return;
     }
     
@@ -767,7 +778,7 @@ void user_menu_cmd (WEdit *edit_widget)
     }
 
     if (menu_lines == 0) {
-	message (1, MSG_ERROR, _(" No appropriative entries found in %s "), menu);
+	message (1, MSG_ERROR, _(" No suitable entries found in %s "), menu);
     } else {
 
     max_cols = min (max (max_cols, col), MAX_ENTRY_LEN);
@@ -799,4 +810,4 @@ void user_menu_cmd (WEdit *edit_widget)
 	g_free (entries);
     g_free (data);
 }
-#endif /* !HAVE_X */
+
