@@ -28,14 +28,13 @@
 
 /* }}} */
 
-/*  [] = "$Id: wtools.c,v 1.25 2001/06/20 17:12:47 proskin Exp $" */
-
 #include <config.h>
 #include <string.h>
 #include <stdio.h>
-#include "tty.h"
 #include <stdarg.h>
+
 #include "global.h"
+#include "tty.h"
 #include "win.h"
 #include "color.h"
 #include "mouse.h"
@@ -46,60 +45,11 @@
 #include "key.h"	/* For mi_getch() */
 #include "dialog.h"	/* For do_refresh() */
 #include "complete.h"   /* INPUT_COMPLETE_CD */
-#include "x.h"
 
 /* }}} */
 
-/* {{{ Common dialog callback */
-
-void
-dialog_repaint (struct Dlg_head *h, int back, int title_fore)
-{
-#ifndef HAVE_X
-    attrset (back);
-    dlg_erase (h);
-    draw_box (h, 1, 1, h->lines - 2, h->cols - 2);
-    attrset (title_fore);
-    if (h->title){
-	dlg_move (h, 1, (h->cols-strlen (h->title))/2);
-	addstr (h->title);
-    }
-#endif
-}
-
-void
-common_dialog_repaint (struct Dlg_head *h)
-{
-    dialog_repaint (h, COLOR_NORMAL, COLOR_HOT_NORMAL);
-}
-
-int
-common_dialog_callback (struct Dlg_head *h, int id, int msg)
-{
-    if (msg == DLG_DRAW)
-	common_dialog_repaint (h);
-    return 0;
-}
-
-/* }}} */
 /* {{{ Listbox utility functions */
 
-#ifdef HAVE_X
-#define listbox_refresh(h)
-#else
-#define listbox_refresh(h)	common_dialog_repaint(h)
-#endif
-
-static int listbox_callback (Dlg_head *h, int id, int msg)
-{
-    switch (msg) {
-    case DLG_DRAW:
-        listbox_refresh(h);
-        return 1;
-    }
-    return 0;
-}
-
 Listbox *create_listbox_window (int cols, int lines, char *title, char *help)
 {
     int xpos, ypos, len;
@@ -124,8 +74,7 @@ Listbox *create_listbox_window (int cols, int lines, char *title, char *help)
 
     /* Create components */
     listbox->dlg = create_dlg (ypos, xpos, lines+6, cols+4, dialog_colors,
-			       listbox_callback, help, "listbox", DLG_CENTER|DLG_GRID);
-    x_set_dialog_title (listbox->dlg, title);	       
+			       NULL, help, title, DLG_CENTER);
     
     listbox->list = listbox_new (2, 2, cols, lines, listbox_finish, 0, "li");
 
@@ -133,7 +82,7 @@ Listbox *create_listbox_window (int cols, int lines, char *title, char *help)
 		button_new (lines+3, (cols/2 + 2) - len/2, 
 		B_CANCEL, NORMAL_BUTTON, cancel_string, 0, 0, "c"));
     add_widget (listbox->dlg, listbox->list);
-    listbox_refresh(listbox->dlg);
+    common_dialog_repaint (listbox->dlg);
     return listbox;
 }
 
@@ -156,35 +105,6 @@ int run_listbox (Listbox *l)
 
 
 /* {{{ Query Dialog functions */
-#ifndef HAVE_GNOME
-struct text_struct {
-    char *text;
-    char *header;
-};
-
-static int query_callback (struct Dlg_head *h, int Id, int Msg)
-{
-#ifndef HAVE_X    
-    struct text_struct *info;
-
-    info = (struct text_struct *) h->data;
-    
-    switch (Msg){
-    case DLG_DRAW:
-	/* designate window */
-	attrset (NORMALC);
-	dlg_erase (h);
-	draw_box (h, 1, 1, h->lines-2, h->cols-2);
-	attrset (HOT_NORMALC);
-	dlg_move (h, 1, (h->cols-strlen (info->header))/2);
-	addstr (info->header);
-	break;
-    }
-#endif
-    return 0;
-}
-
-
 Dlg_head *last_query_dlg;
 
 static int sel_pos = 0;
@@ -200,20 +120,16 @@ int query_dialog (char *header, char *text, int flags, int count, ...)
     int xpos, ypos;
     int cols, lines;
     char *cur_name;
-    static int query_colors [4];
-    static struct text_struct pass;
-#ifdef HAVE_X    
-    static char *buttonnames [10];
-#endif
-    
+    static const int *query_colors;
+
     /* set dialog colors */
-    query_colors [0] = (flags & D_ERROR) ? ERROR_COLOR :  Q_UNSELECTED_COLOR;
-    query_colors [1] = (flags & D_ERROR) ? REVERSE_COLOR : Q_SELECTED_COLOR;
-    query_colors [2] = (flags & D_ERROR) ? ERROR_COLOR : COLOR_HOT_NORMAL;
-    query_colors [3] = (flags & D_ERROR) ? COLOR_HOT_NORMAL :  COLOR_HOT_FOCUS;
+    if (flags & D_ERROR)
+	query_colors = alarm_colors;
+    else
+	query_colors = dialog_colors;
     
     if (header == MSG_ERROR)
-	header = _(" Error ");
+	header = _("Error");
     
     if (count > 0){
 	va_start (ap, count);
@@ -232,20 +148,10 @@ int query_dialog (char *header, char *text, int flags, int count, ...)
     lines += 4 + (count > 0 ? 2 : 0);
     xpos = COLS/2 - cols/2;
     ypos = LINES/3 - (lines-3)/2;
-    pass.header = header;
-    pass.text   = text;
 
     /* prepare dialog */
-    query_dlg = create_dlg (ypos, xpos, lines, cols, query_colors,
-			    query_callback, "[QueryBox]", "query", DLG_NONE);
-    x_set_dialog_title (query_dlg, header);
-
-    /* The data we need to pass to the callback */
-    query_dlg->cols = cols; 
-    query_dlg->lines = lines; 
-    query_dlg->data  = &pass;
-	
-    query_dlg->direction = DIR_BACKWARD;
+    query_dlg = create_dlg (ypos, xpos, lines, cols, query_colors, NULL,
+			    "[QueryBox]", header, DLG_BACKWARD);
 
     if (count > 0){
 
@@ -279,17 +185,8 @@ int query_dialog (char *header, char *text, int flags, int count, ...)
 	/* free used memory */
 	destroy_dlg (query_dlg);
     } else {
-#ifdef HAVE_X
-	add_widget (query_dlg, button_new(0, 0, B_EXIT, NORMAL_BUTTON,
-					  _("&Ok"), 0, 0, NULL));
-
-	add_widget (query_dlg, label_new (2, 3, text, NULL));
-	run_dlg (query_dlg);
-	destroy_dlg (query_dlg);
-#else
 	add_widget (query_dlg, label_new (2, 3, text, NULL));
 	add_widget (query_dlg, button_new(0, 0, 0, HIDDEN_BUTTON, "-", 0, 0, NULL));
-#endif /* HAVE_X */
 	last_query_dlg = query_dlg;
     }
     sel_pos = 0;
@@ -306,7 +203,8 @@ void query_set_sel (int new_sel)
 /* {{{ The message function */
 
 /* To show nice messages to the users */
-Dlg_head *message (int error, char *header, const char *text, ...)
+struct Dlg_head *
+message (int error, char *header, const char *text, ...)
 {
     va_list  args;
     char     buffer [4096];
@@ -315,7 +213,7 @@ Dlg_head *message (int error, char *header, const char *text, ...)
     /* Setup the display information */
     strcpy (buffer, "\n");
     va_start (args, text);
-    g_vsnprintf (&buffer [1], sizeof (buffer) - 1, text, args);
+    g_vsnprintf (&buffer [1], sizeof (buffer) - 2, text, args);
     strcat (buffer, "\n");
     va_end (args);
     
@@ -331,81 +229,15 @@ Dlg_head *message (int error, char *header, const char *text, ...)
 	return d;
     return 0;
 }
-#endif
-/* }}} */
-
-/* {{{ The chooser routines */
-
-static int  remove_callback (int i, void *data)
-{
-    Chooser *c = (Chooser *) data;
-    
-    listbox_remove_current (c->listbox, 0);
-
-    dlg_select_widget (c->dialog, c->listbox);
-    dlg_select_nth_widget (c->dialog, 0);
-    
-    /* Return: do not abort dialog */
-    return 0;
-}
-
-Chooser *new_chooser (int lines, int cols, char *help, int flags)
-{
-    Chooser  *c;
-    int      button_lines;
-
-    c =g_new (Chooser, 1);
-    c->dialog = create_dlg (0, 0, lines, cols, dialog_colors, common_dialog_callback,
-			    help, "chooser", DLG_CENTER | DLG_GRID);
-    
-    c->dialog->lines = lines;
-    c->dialog->cols  = cols;
-    
-    button_lines = flags & CHOOSE_EDITABLE ? 3 : 0;
-    
-    c->listbox = listbox_new (1, 1, cols-2, lines-button_lines,
-			   listbox_finish, 0, "listbox");
-    
-    if (button_lines){
-	add_widget (c->dialog, button_new (lines-button_lines+1,
-				20, B_ENTER, DEFPUSH_BUTTON, _("&Remove"),
-				remove_callback, c, "button-remove"));
-	add_widget (c->dialog, button_new (lines-button_lines+1,
-				    4, B_CANCEL, NORMAL_BUTTON, _("&Cancel"),
-				    0, 0, "button-cancel"));
-    }		    
-    add_widget (c->dialog, c->listbox);
-    return c;
-}
-
-int run_chooser (Chooser *c)
-{
-    run_dlg (c->dialog);
-    return c->dialog->ret_value;
-}
-
-void destroy_chooser (Chooser *c)
-{
-    destroy_dlg (c->dialog);
-}
-
 /* }}} */
 
 /* {{{ Quick dialog routines */
 
-#ifndef HAVE_X
-
 static int quick_callback (struct Dlg_head *h, int id, int Msg)
 {
     switch (Msg){
     case DLG_DRAW:
-	attrset (COLOR_NORMAL);
-	dlg_erase (h);
-	draw_box (h, 1, 1, h->lines-2, h->cols-2);
-	
-	attrset (COLOR_HOT_NORMAL);
-	dlg_move (h, 1,((h->cols-strlen (h->data))/2));
-	addstr (h->data);
+	common_dialog_repaint (h);
 	break;
     case DLG_KEY:
 	if (id == '\n'){
@@ -419,59 +251,74 @@ static int quick_callback (struct Dlg_head *h, int id, int Msg)
 
 #define I18N(x) (do_int && *x ? (x = _(x)): x)
 
-int quick_dialog_skip (QuickDialog *qd, int nskip)
+int
+quick_dialog_skip (QuickDialog *qd, int nskip)
 {
     Dlg_head *dd;
-    void     *widget;
-    WRadio   *r;
-    int      xpos;
-    int      ypos;
-    int      return_val;
-    WInput   *input;
+    void *widget;
+    WRadio *r;
+    int xpos;
+    int ypos;
+    int return_val;
+    WInput *input;
     QuickWidget *qw;
-    int      do_int;
+    int do_int;
+    int count = 0;		/* number of quick widgets */
+    int curr_widget;		/* number of the current quick widget */
+    Widget **widgets;		/* table of corresponding widgets */
 
-    if (!qd->i18n){
+    if (!qd->i18n) {
 	qd->i18n = 1;
 	do_int = 1;
 	if (*qd->title)
 	    qd->title = _(qd->title);
     } else
 	do_int = 0;
-    
+
     if (qd->xpos == -1)
-        dd = create_dlg (0, 0, qd->ylen, qd->xlen, dialog_colors, quick_callback,
-		         qd->help, qd->class, DLG_CENTER | DLG_TRYUP | DLG_GRID);
+	dd = create_dlg (0, 0, qd->ylen, qd->xlen, dialog_colors,
+			 quick_callback, qd->help, qd->title,
+			 DLG_CENTER | DLG_TRYUP);
     else
-        dd = create_dlg (qd->ypos, qd->xpos, qd->ylen, qd->xlen, dialog_colors, 
-                         quick_callback,
-		         qd->help, qd->class, DLG_GRID);
+	dd = create_dlg (qd->ypos, qd->xpos, qd->ylen, qd->xlen,
+			 dialog_colors, quick_callback, qd->help,
+			 qd->title, DLG_NONE);
 
-    x_set_dialog_title (dd, qd->title);
-    
     /* We pass this to the callback */
-    dd->cols  = qd->xlen;
+    dd->cols = qd->xlen;
     dd->lines = qd->ylen;
-    dd->data  = qd->title;
 
-    for (qw = qd->widgets; qw->widget_type; qw++){
-	xpos = (qd->xlen * qw->relative_x)/qw->x_divisions;
-	ypos = (qd->ylen * qw->relative_y)/qw->y_divisions;
-	
-	switch (qw->widget_type){
+    /* Count widgets */
+    for (qw = qd->widgets; qw->widget_type; qw++) {
+	count++;
+    }
+
+    widgets = (Widget **) g_new (Widget *, count);
+
+    for (curr_widget = 0, qw = qd->widgets; qw->widget_type; qw++) {
+	xpos = (qd->xlen * qw->relative_x) / qw->x_divisions;
+	ypos = (qd->ylen * qw->relative_y) / qw->y_divisions;
+
+	switch (qw->widget_type) {
 	case quick_checkbox:
-	    widget = check_new (ypos, xpos, *qw->result, I18N (qw->text), qw->tkname);
+	    widget =
+		check_new (ypos, xpos, *qw->result, I18N (qw->text),
+			   qw->tkname);
 	    break;
 
 	case quick_radio:
-	    r = radio_new (ypos, xpos, qw->hotkey_pos, qw->str_result, 1, qw->tkname);
+	    r = radio_new (ypos, xpos, qw->hotkey_pos, qw->str_result, 1,
+			   qw->tkname);
 	    r->pos = r->sel = qw->value;
 	    widget = r;
 	    break;
-	    
+
 	case quick_button:
-	    widget = button_new (ypos, xpos, qw->value, (qw->value==B_ENTER) ? DEFPUSH_BUTTON : NORMAL_BUTTON,
-	    I18N (qw->text), 0, 0, qw->tkname);
+	    widget =
+		button_new (ypos, xpos, qw->value,
+			    (qw->value ==
+			     B_ENTER) ? DEFPUSH_BUTTON : NORMAL_BUTTON,
+			    I18N (qw->text), 0, 0, qw->tkname);
 	    break;
 
 	    /* We use the hotkey pos as the field length */
@@ -481,20 +328,20 @@ int quick_dialog_skip (QuickDialog *qd, int nskip)
 	    input->is_password = qw->value == 1;
 	    input->point = 0;
 	    if (qw->value & 2)
-	        input->completion_flags |= INPUT_COMPLETE_CD;
+		input->completion_flags |= INPUT_COMPLETE_CD;
 	    widget = input;
 	    break;
 
 	case quick_label:
-	    widget = label_new (ypos, xpos, I18N(qw->text), qw->tkname);
+	    widget = label_new (ypos, xpos, I18N (qw->text), qw->tkname);
 	    break;
-	    
+
 	default:
 	    widget = 0;
 	    fprintf (stderr, "QuickWidget: unknown widget type\n");
 	    break;
 	}
-	qw->the_widget = widget;
+	widgets[curr_widget++] = widget;
 	add_widget (dd, widget);
     }
 
@@ -504,26 +351,29 @@ int quick_dialog_skip (QuickDialog *qd, int nskip)
     run_dlg (dd);
 
     /* Get the data if we found something interesting */
-    if (dd->ret_value != B_CANCEL){
-	for (qw = qd->widgets; qw->widget_type; qw++){
-	    switch (qw->widget_type){
+    if (dd->ret_value != B_CANCEL) {
+	for (curr_widget = 0, qw = qd->widgets; qw->widget_type; qw++) {
+	    Widget *w = widgets[curr_widget++];
+
+	    switch (qw->widget_type) {
 	    case quick_checkbox:
-		*qw->result = ((WCheck *) qw->the_widget)->state & C_BOOL;
+		*qw->result = ((WCheck *) w)->state & C_BOOL;
 		break;
 
 	    case quick_radio:
-		*qw->result = ((WRadio *) qw->the_widget)->sel;
+		*qw->result = ((WRadio *) w)->sel;
 		break;
-		
+
 	    case quick_input:
-		*qw->str_result = g_strdup (((WInput *) qw->the_widget)->buffer);
+		*qw->str_result = g_strdup (((WInput *) w)->buffer);
 		break;
 	    }
 	}
     }
     return_val = dd->ret_value;
     destroy_dlg (dd);
-    
+    g_free (widgets);
+
     return return_val;
 }
 
@@ -537,24 +387,28 @@ int quick_dialog (QuickDialog *qd)
 /* {{{ Input routines */
 
 #define INPUT_INDEX 2
-char *real_input_dialog_help (char *header, char *text, char *help, char *def_text)
+char *
+real_input_dialog_help (char *header, char *text, char *help,
+			char *def_text)
 {
     QuickDialog Quick_input;
-    QuickWidget quick_widgets [] = {
-    { quick_button, 6, 10, 1, 0, N_("&Cancel"), 0, B_CANCEL, 0, 0,
-	  "button-cancel" },
-    { quick_button, 3, 10, 1, 0, N_("&Ok"), 0, B_ENTER, 0, 0,
-	  "button-ok" },
-    { quick_input,  4, 80, 0, 0, "", 58, 0, 0, 0, 0 },
-    { quick_label,  3, 80, 2, 0, "", 0, 0, 0, 0, "label" },
-    { 0 } };
-    
+    QuickWidget quick_widgets[] = {
+	{quick_button, 6, 10, 1, 0, N_("&Cancel"), 0, B_CANCEL, 0, 0,
+	 "button-cancel"},
+	{quick_button, 3, 10, 1, 0, N_("&OK"), 0, B_ENTER, 0, 0,
+	 "button-ok"},
+	{quick_input, 4, 80, 0, 0, "", 58, 0, 0, 0, 0},
+	{quick_label, 4, 80, 2, 0, "", 0, 0, 0, 0, "label"},
+	{0}
+    };
+
     int len;
     int i;
     int lines;
+    int ret;
     char *my_str;
     char tk_name[64] = "inp|";
-    
+
 /* we need a unique name for tkname because widget.c:history_tool()
    needs a unique name for each dialog - using the header is ideal */
 
@@ -564,53 +418,54 @@ char *real_input_dialog_help (char *header, char *text, char *help, char *def_te
 
     len = max (strlen (header), msglen (text, &lines)) + 4;
     len = max (len, 64);
-    
-    /* Translators should take care as "Password" or its translations
-    are used to identify password boxes and hide characters with "*" */
-    my_str = _("Password:");
-    if (strncmp (text, my_str, strlen (my_str)-1) == 0){
-	quick_widgets [INPUT_INDEX].value = 1;
-	tk_name[3]=0;
+
+    /* The special value of def_text is used to identify password boxes
+       and hide characters with "*".  Don't save passwords in history! */
+    if (def_text == INPUT_PASSWORD) {
+	quick_widgets[INPUT_INDEX].value = 1;
+	tk_name[3] = 0;
+	def_text = "";
     } else {
-	quick_widgets [INPUT_INDEX].value = 0;
+	quick_widgets[INPUT_INDEX].value = 0;
     }
 
 #ifdef ENABLE_NLS
-	/* 
-	 * An attempt to place buttons symmetrically, based on actual i18n
-	 * length of the string. It looks nicer with i18n (IMO) - alex
-	 */
-	quick_widgets [0].relative_x = len/2 + 4;
-	quick_widgets [1].relative_x = 
-		len/2 - (strlen (_(quick_widgets [1].text)) + 9);
-	quick_widgets [0].x_divisions = quick_widgets [1].x_divisions = len;
-#endif /* ENABLE_NLS */
-    
-    Quick_input.xlen  = len;
-    Quick_input.xpos  = -1;
+    /* 
+     * An attempt to place buttons symmetrically, based on actual i18n
+     * length of the string. It looks nicer with i18n (IMO) - alex
+     */
+    quick_widgets[0].relative_x = len / 2 + 4;
+    quick_widgets[1].relative_x =
+	len / 2 - (strlen (_(quick_widgets[1].text)) + 9);
+    quick_widgets[0].x_divisions = quick_widgets[1].x_divisions = len;
+#endif				/* ENABLE_NLS */
+
+    Quick_input.xlen = len;
+    Quick_input.xpos = -1;
     Quick_input.title = header;
-    Quick_input.help  = help;
-    Quick_input.class = "quick_input";
-    Quick_input.i18n  = 0;
-    quick_widgets [INPUT_INDEX+1].text = text;
-    quick_widgets [INPUT_INDEX].text = def_text;
+    Quick_input.help = help;
+    Quick_input.i18n = 0;
+    quick_widgets[INPUT_INDEX + 1].text = g_strstrip (g_strdup (text));
+    quick_widgets[INPUT_INDEX].text = def_text;
 
     for (i = 0; i < 4; i++)
-	quick_widgets [i].y_divisions = lines+6;
-    Quick_input.ylen  = lines + 6;
+	quick_widgets[i].y_divisions = lines + 6;
+    Quick_input.ylen = lines + 6;
 
     for (i = 0; i < 3; i++)
-	quick_widgets [i].relative_y += 2 + lines;
+	quick_widgets[i].relative_y += 2 + lines;
+
+    quick_widgets[INPUT_INDEX].str_result = &my_str;
 
-    quick_widgets [INPUT_INDEX].str_result = &my_str;
-    
     Quick_input.widgets = quick_widgets;
-    if (quick_dialog (&Quick_input) != B_CANCEL){
-	return *(quick_widgets [INPUT_INDEX].str_result);
+    ret = quick_dialog (&Quick_input);
+    g_free (quick_widgets[INPUT_INDEX + 1].text);
+
+    if (ret != B_CANCEL) {
+	return *(quick_widgets[INPUT_INDEX].str_result);
     } else
 	return 0;
 }
-#endif /* !HAVE_X */
 
 char *input_dialog (char *header, char *text, char *def_text)
 {
