@@ -1,17 +1,13 @@
 #ifndef __WTOOLS_H
 #define __WTOOLS_H
 
-/* Dialog default background repaint routines */
-void dialog_repaint (struct Dlg_head *h, int back, int title_fore);
-void common_dialog_repaint (struct Dlg_head *h);
-
-/* For common dialogs, just repaint background */
-int  common_dialog_callback (struct Dlg_head *h, int id, int msg);
+struct Dlg_head;
+struct WListbox;
 
 /* Listbox utility functions */
 typedef struct {
-    Dlg_head *dlg;
-    WListbox *list;
+    struct Dlg_head *dlg;
+    struct WListbox *list;
 } Listbox;
 
 Listbox *create_listbox_window (int cols, int lines, char *title, char *help);
@@ -44,9 +40,7 @@ typedef struct {
     int  value;			/* Buttons only: value of button */
     int  *result;		/* Checkbutton: where to store result */
     char **str_result;		/* Input lines: destination  */
-    WLay layout;		/* XView Layouting stuff */
     char *tkname;		/* Name of the widget used for Tk only */
-    void *the_widget;		/* For the quick quick dialog manager */
 } QuickWidget;
     
 typedef struct {
@@ -54,7 +48,6 @@ typedef struct {
     int  xpos, ypos; /* if -1, then center the dialog */
     char *title;
     char *help;
-    char *class;		/* Used for Tk's class name */
     QuickWidget *widgets;
     int  i18n;			/* If true, internationalization has happened */
 } QuickDialog;
@@ -62,22 +55,11 @@ typedef struct {
 int quick_dialog (QuickDialog *qd);
 int quick_dialog_skip (QuickDialog *qd, int nskip);
 
-/* Choosers */
-
-#define CHOOSE_EDITABLE  1
-#define CHOOSE_BROWSE    0
-
-/* Chooser dialog boxes */
-typedef struct {
-    Dlg_head *dialog;
-    WListbox *listbox;
-} Chooser;
-
-Chooser *new_chooser (int lines, int cols, char *help, int flags);
-int run_chooser (Chooser *c);
-void destroy_chooser (Chooser *c);
-
 /* The input dialogs */
+
+/* Pass this as def_text to request a password */
+#define INPUT_PASSWORD ((char *) -1)
+
 char *input_dialog (char *header, char *text, char *def_text);
 char *input_dialog_help (char *header, char *text, char *help, char *def_text);
 char *input_expand_dialog (char *header, char *text, char *def_text);
@@ -85,4 +67,20 @@ char *real_input_dialog (char *header, char *text, char *def_text);
 char *real_input_dialog_help (char *header, char *text, char *help, char *def_text);
 
 void query_set_sel (int new_sel);
+
+struct Dlg_head *message (int error, char *header, const char *text, ...)
+    __attribute__ ((format (printf, 3, 4)));
+
+/* Use this as header for message() - it expands to "Error" */
+#define MSG_ERROR ((char *) -1)
+
+int query_dialog (char *header, char *text, int flags, int count, ...);
+
+/* flags for message() and query_dialog() */
+enum {
+   D_NORMAL = 0,
+   D_ERROR  = 1,
+   D_INSERT = 2
+} /* dialog options */;
+
 #endif	/* __WTOOLS_H */
