@@ -3,8 +3,6 @@
    
    Written by: 2000 Jan Hudec
 
-   $Id: cpio.c,v 1.14 2001/08/19 03:38:53 proskin Exp $
-
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
    as published by the Free Software Foundation; either version 2 of
@@ -20,10 +18,9 @@
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include <config.h>
-#include "xdirentry.h"
-#include "utilvfs.h"
-#include <glib.h>
 #include <errno.h>
+#include "utilvfs.h"
+#include "xdirentry.h"
 
 /* #include "utilvfs.h" */
 
@@ -120,6 +117,8 @@ static int cpio_skip_padding(vfs_s_super *super)
     case CPIO_NEWC:
     case CPIO_CRC:
 	return CPIO_SEEK_CUR(super, (4 - (CPIO_POS(super) % 4)) % 4);
+    case CPIO_OLDC:
+	return CPIO_POS(super);
     default:
 	g_assert_not_reached();
 	return 42; /* & the compiler is happy :-) */
@@ -134,12 +133,12 @@ static void cpio_free_archive(vfs *me, vfs_s_super *super)
 
 static int cpio_open_cpio_file(vfs *me, vfs_s_super *super, char *name)
 {
-    int fd, size, type;
+    int fd, type;
     mode_t mode;
     vfs_s_inode *root;
 
     if((fd = mc_open(name, O_RDONLY)) == -1) {
-	message_2s(1, MSG_ERROR, _("Couldn't open cpio archive\n%s"), name);
+	message_2s(1, MSG_ERROR, _("Cannot open cpio archive\n%s"), name);
 	return -1;
     }
 
@@ -148,14 +147,14 @@ static int cpio_open_cpio_file(vfs *me, vfs_s_super *super, char *name)
     mc_stat(name, &(super->u.cpio.stat));
     super->u.cpio.type = CPIO_UNKNOWN;
 
-    size = is_gunzipable(fd, &type);
-    if(size > 0) {
+    type = get_compression_type(fd);
+    if (type != COMPRESSION_NONE) {
 	char *s;
 
 	mc_close(fd);
 	s = g_strconcat(name, decompress_extension(type), NULL);
 	if((fd = mc_open(s, O_RDONLY)) == -1) {
-	    message_2s(1, MSG_ERROR, _("Couldn't open cpio archive\n%s"), s);
+	    message_2s(1, MSG_ERROR, _("Cannot open cpio archive\n%s"), s);
 	    g_free(s);
 	    return -1;
 	}
@@ -263,9 +262,10 @@ static int cpio_read_bin_head(vfs *me, vfs_s_super *super)
     g_assert(buf.c_magic == 070707);
 
     name = g_malloc(buf.c_namesize);
-    if((len = mc_read(super->u.cpio.fd, name, buf.c_namesize)) < buf.c_namesize)
+    if((len = mc_read(super->u.cpio.fd, name, buf.c_namesize)) < buf.c_namesize){
+	g_free(name);
 	return STATUS_EOF;
-
+    }
     CPIO_POS(super) += len;
     cpio_skip_padding(super);
 
@@ -293,27 +293,28 @@ static int cpio_read_oldc_head(vfs *me, vfs_s_super *super)
 {
     struct new_cpio_header hd;
     struct stat stat;
-    char *buf[HEAD_LENGTH + 1];
+    char buf[HEAD_LENGTH + 1];
     int len;
     char *name;
 
-    if((len = mc_read(super->u.cpio.fd, (void *)buf, HEAD_LENGTH)) < HEAD_LENGTH)
+    if((len = mc_read(super->u.cpio.fd, buf, HEAD_LENGTH)) < HEAD_LENGTH)
 	return STATUS_EOF;
     CPIO_POS(super) += len;
-    buf[HEAD_LENGTH + 1] = 0;
+    buf[HEAD_LENGTH] = 0;
 
-    if(sscanf((void *)buf, "070707%6lo%6lo%6lo%6lo%6lo%6lo%6lo%11lo%6lo%11lo",
+    if(sscanf(buf, "070707%6lo%6lo%6lo%6lo%6lo%6lo%6lo%11lo%6lo%11lo",
 	      &hd.c_dev, &hd.c_ino, &hd.c_mode, &hd.c_uid, &hd.c_gid,
 	      &hd.c_nlink, &hd.c_rdev, &hd.c_mtime,
 	      &hd.c_namesize, &hd.c_filesize) < 10) {
-	message_2s(1, MSG_ERROR, _("Corrupt cpio header encountered in\n%s"), super->name);
+	message_2s(1, MSG_ERROR, _("Corrupted cpio header encountered in\n%s"), super->name);
 	return STATUS_FAIL;
     }
 
     name = g_malloc(hd.c_namesize);
-    if((len = mc_read(super->u.cpio.fd, name, hd.c_namesize)) < hd.c_namesize)
+    if((len = mc_read(super->u.cpio.fd, name, hd.c_namesize)) < hd.c_namesize) {
+	g_free (name);
 	return STATUS_EOF;
-
+    }
     CPIO_POS(super) +=  len;
     cpio_skip_padding(super);
 
@@ -348,14 +349,15 @@ static int cpio_read_crc_head(vfs *me, vfs_s_super *super)
     if((len = mc_read(super->u.cpio.fd, buf, HEAD_LENGTH)) < HEAD_LENGTH)
 	return STATUS_EOF;
     CPIO_POS(super) += len;
-    buf[HEAD_LENGTH + 1] = 0;
+    buf[HEAD_LENGTH] = 0;
 
     if(sscanf(buf, "%6ho%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx%8lx",
 	      &hd.c_magic, &hd.c_ino, &hd.c_mode, &hd.c_uid, &hd.c_gid,
 	      &hd.c_nlink,  &hd.c_mtime, &hd.c_filesize,
 	      &hd.c_dev, &hd.c_devmin, &hd.c_rdev, &hd.c_rdevmin,
 	      &hd.c_namesize, &hd.c_chksum) < 14) {
-	message_2s(1, MSG_ERROR, _("Corrupt cpio header encountered in\n%s"), super->name);
+	message_2s(1, MSG_ERROR, _("Corrupted cpio header encountered in\n%s"),
+		   super->name);
 	return STATUS_FAIL;
     }
 
@@ -364,9 +366,10 @@ static int cpio_read_crc_head(vfs *me, vfs_s_super *super)
 	return STATUS_FAIL;
 
     name = g_malloc(hd.c_namesize);
-    if((len = mc_read(super->u.cpio.fd, name, hd.c_namesize)) < hd.c_namesize)
+    if((len = mc_read(super->u.cpio.fd, name, hd.c_namesize)) < hd.c_namesize){
+	g_free (name);
 	return STATUS_EOF;
-
+    }
     CPIO_POS(super) += len;
     cpio_skip_padding(super);
 
@@ -447,7 +450,7 @@ static int cpio_create_entry(vfs *me, vfs_s_super *super, struct stat *stat, cha
 		   'No such file or directory' is such case) */
 
 	if(!S_ISDIR(entry->ino->st.st_mode)) { /* This can be considered archive inconsistency */
-	    message_2s(1, MSG_ERROR, _("%s contains duplicit entries! Skiping!"), super->name);
+	    message_2s(1, MSG_ERROR, _("%s contains duplicate entries! Skipping!"), super->name);
 	} else {
 	    entry->ino->st.st_mode = stat->st_mode;
 	    entry->ino->st.st_uid = stat->st_uid;
@@ -490,6 +493,7 @@ static int cpio_create_entry(vfs *me, vfs_s_super *super, struct stat *stat, cha
 		return STATUS_EOF;
 	    }
 	    inode->linkname[stat->st_size] = 0; /* Linkname stored without terminating \0 !!! */
+	    CPIO_POS(super) += stat->st_size;
 	    cpio_skip_padding(super);
 	} else {
 	    CPIO_SEEK_CUR(super, stat->st_size);
@@ -497,6 +501,7 @@ static int cpio_create_entry(vfs *me, vfs_s_super *super, struct stat *stat, cha
 
     } /* !entry */
 
+    g_free (name);
     return STATUS_OK;
 }
 
@@ -536,18 +541,18 @@ static void *cpio_super_check(vfs *me, char *archive_name, char *op)
     return &sb;
 }
 
-static int cpio_super_same(vfs *me, struct vfs_s_super *parc, char *archive_name, char *op, void *cookie)
-{	
+static int
+cpio_super_same (vfs *me, struct vfs_s_super *parc, char *archive_name,
+		 char *op, void *cookie)
+{
     struct stat *archive_stat = cookie;	/* stat of main archive */
 
-    if(strcmp(parc->name, archive_name)) return 0;
+    if (strcmp (parc->name, archive_name))
+	return 0;
 
-    if(vfs_uid && (!(archive_stat->st_mode & 0004)))
-	if((archive_stat->st_gid != vfs_gid) || !(archive_stat->st_mode & 0040))
-	    if((archive_stat->st_uid != vfs_uid) || !(archive_stat->st_mode & 0400))
-		return 0;
-/* Has the cached archive been changed on the disk? */
-    if(parc->u.cpio.stat.st_mtime < archive_stat->st_mtime) { /* Yes, reload! */
+    /* Has the cached archive been changed on the disk? */
+    if (parc->u.cpio.stat.st_mtime < archive_stat->st_mtime) {
+	/* Yes, reload! */
 	(*vfs_cpiofs_ops.free) ((vfsid) parc);
 	vfs_rmstamp (&vfs_cpiofs_ops, (vfsid) parc, 0);
 	return 2;
@@ -607,8 +612,12 @@ static struct vfs_s_data cpiofs_data = {
 
     vfs_s_find_entry_tree,
     NULL,
+    NULL,
+    NULL,
+
+    NULL,
+    NULL,
     NULL
-    /* ??? */
 };
 
 vfs vfs_cpiofs_ops = {
