@@ -45,16 +45,6 @@
 #undef HAVE_TERMIOS_H
 #endif
 
-#ifdef RELIANTUNIX
-/*
- * <unistd.h> has to be included before any other to get
- * large file support on Reliant UNIX
- */
-#ifdef HAVE_UNISTD_H
-#include <unistd.h>
-#endif
-#endif /* RELIANTUNIX */
-
 #include <sys/types.h>
 
 #ifdef TIME_WITH_SYS_TIME
@@ -342,35 +332,11 @@
 #endif
 #endif /* HAVE_NETGROUP */
 
-/*
- * Define VOLATILE if needed.
- */
-
-#if defined(HAVE_VOLATILE)
-#define VOLATILE volatile
-#else
-#define VOLATILE
-#endif
-
-/*
- * Define SIG_ATOMIC_T if needed.
- */
-
-#if defined(HAVE_SIG_ATOMIC_T_TYPE)
-#define SIG_ATOMIC_T sig_atomic_t
-#else
-#define SIG_ATOMIC_T int
-#endif
-
 #ifndef uchar
 #define uchar unsigned char
 #endif
 
-#ifdef HAVE_UNSIGNED_CHAR
 #define schar signed char
-#else
-#define schar char
-#endif
 
 /*
    Samba needs type definitions for int16, int32, uint16 and uint32.
@@ -444,15 +410,11 @@
  */
 
 #ifndef SMB_INO_T
-#  if defined(HAVE_EXPLICIT_LARGEFILE_SUPPORT) && defined(HAVE_INO64_T)
-#    define SMB_INO_T ino64_t
-#  else
 #    define SMB_INO_T ino_t
-#  endif
 #endif
 
 #ifndef LARGE_SMB_INO_T
-#  if (defined(HAVE_EXPLICIT_LARGEFILE_SUPPORT) && defined(HAVE_INO64_T)) || (defined(SIZEOF_INO_T) && (SIZEOF_INO_T == 8))
+#  if defined(SIZEOF_INO_T) && (SIZEOF_INO_T == 8)
 #    define LARGE_SMB_INO_T 1
 #  endif
 #endif
@@ -464,11 +426,7 @@
 #endif
 
 #ifndef SMB_OFF_T
-#  if defined(HAVE_EXPLICIT_LARGEFILE_SUPPORT) && defined(HAVE_OFF64_T)
-#    define SMB_OFF_T off64_t
-#  else
 #    define SMB_OFF_T off_t
-#  endif
 #endif
 
 #define SMB_OFF_T_BITS (sizeof(SMB_OFF_T)*8)
@@ -479,7 +437,7 @@
  */
 
 #ifndef LARGE_SMB_OFF_T
-#  if (defined(HAVE_EXPLICIT_LARGEFILE_SUPPORT) && defined(HAVE_OFF64_T)) || (defined(SIZEOF_OFF_T) && (SIZEOF_OFF_T == 8))
+#  if defined(SIZEOF_OFF_T) && (SIZEOF_OFF_T == 8)
 #    define LARGE_SMB_OFF_T 1
 #  endif
 #endif
@@ -495,11 +453,7 @@
  */
 
 #ifndef SMB_STRUCT_STAT
-#  if defined(HAVE_EXPLICIT_LARGEFILE_SUPPORT) && defined(HAVE_STAT64) && defined(HAVE_OFF64_T)
-#    define SMB_STRUCT_STAT struct stat64
-#  else
 #    define SMB_STRUCT_STAT struct stat
-#  endif
 #endif
 
 /*
@@ -507,11 +461,7 @@
  */
 
 #ifndef SMB_STRUCT_DIRENT
-#  if defined(HAVE_EXPLICIT_LARGEFILE_SUPPORT) && defined(HAVE_STRUCT_DIRENT64)
-#    define SMB_STRUCT_DIRENT struct dirent64
-#  else
 #    define SMB_STRUCT_DIRENT struct dirent
-#  endif
 #endif
 
 /*
@@ -519,35 +469,19 @@
  */
 
 #ifndef SMB_STRUCT_FLOCK
-#  if defined(HAVE_EXPLICIT_LARGEFILE_SUPPORT) && defined(HAVE_STRUCT_FLOCK64) && defined(HAVE_OFF64_T)
-#    define SMB_STRUCT_FLOCK struct flock64
-#  else
 #    define SMB_STRUCT_FLOCK struct flock
-#  endif
 #endif
 
 #ifndef SMB_F_SETLKW
-#  if defined(HAVE_EXPLICIT_LARGEFILE_SUPPORT) && defined(HAVE_STRUCT_FLOCK64) && defined(HAVE_OFF64_T)
-#    define SMB_F_SETLKW F_SETLKW64
-#  else
 #    define SMB_F_SETLKW F_SETLKW
-#  endif
 #endif
 
 #ifndef SMB_F_SETLK
-#  if defined(HAVE_EXPLICIT_LARGEFILE_SUPPORT) && defined(HAVE_STRUCT_FLOCK64) && defined(HAVE_OFF64_T)
-#    define SMB_F_SETLK F_SETLK64
-#  else
 #    define SMB_F_SETLK F_SETLK
-#  endif
 #endif
 
 #ifndef SMB_F_GETLK
-#  if defined(HAVE_EXPLICIT_LARGEFILE_SUPPORT) && defined(HAVE_STRUCT_FLOCK64) && defined(HAVE_OFF64_T)
-#    define SMB_F_GETLK F_GETLK64
-#  else
 #    define SMB_F_GETLK F_GETLK
-#  endif
 #endif
 
 #if defined(HAVE_LONGLONG)
@@ -669,16 +603,6 @@ extern int errno;
 #define MAP_FILE 0
 #endif
 
-#ifdef HAVE_SYSV_IPC
-#ifndef HAVE_UNION_SEMUN
-union semun {
-	int val;
-	struct semid_ds *buf;
-	unsigned short *array;
-};
-#endif
-#endif
-
 #if (!defined(WITH_NISPLUS) && !defined(WITH_LDAP))
 #define USE_SMBPASS_DB 1
 #endif
@@ -699,10 +623,6 @@ union semun {
 #define PASSWORD_LENGTH 8
 #endif
 
-#ifdef REPLACE_INET_NTOA
-#define inet_ntoa rep_inet_ntoa
-#endif
-
 #ifndef HAVE_PIPE
 #define SYNC_DNS 1
 #endif
@@ -735,24 +655,6 @@ union semun {
 #define ULTRIX_AUTH 1
 #endif
 
-#ifdef HAVE_LIBREADLINE
-#  ifdef HAVE_READLINE_READLINE_H
-#    include <readline/readline.h>
-#    ifdef HAVE_READLINE_HISTORY_H
-#      include <readline/history.h>
-#    endif
-#  else
-#    ifdef HAVE_READLINE_H
-#      include <readline.h>
-#      ifdef HAVE_HISTORY_H
-#        include <history.h>
-#      endif
-#    else
-#      undef HAVE_LIBREADLINE
-#    endif
-#  endif
-#endif
-
 #ifndef HAVE_STRDUP
 char *strdup(const char *s);
 #endif
