@@ -190,7 +190,7 @@ static void cli_setup_packet(struct cli_state *cli)
 	}
 }
 
-
+#if 0
 /*****************************************************************************
  Convert a character pointer in a cli_call_api() response to a form we can use.
  This function contains code to prevent core dumps if the server returns 
@@ -213,7 +213,7 @@ static char *fix_char_ptr(unsigned int datap, unsigned int converter,
 		}
 	}
 }
-
+#endif /* 0 */
 /****************************************************************************
   send a SMB trans or trans2 request
   ****************************************************************************/
@@ -535,7 +535,7 @@ BOOL cli_NetWkstaUserLogon(struct cli_state *cli,char *user, char *workstation)
 /****************************************************************************
 call a NetShareEnum - try and browse available connections on a host
 ****************************************************************************/
-BOOL cli_RNetShareEnum(struct cli_state *cli, void (*fn)(const char *, uint32, const char *))
+int cli_RNetShareEnum(struct cli_state *cli, void (*fn)(const char *, uint32, const char *, void *), void * state)
 {
   char *rparam = NULL;
   char *rdata = NULL;
@@ -553,12 +553,16 @@ BOOL cli_RNetShareEnum(struct cli_state *cli, void (*fn)(const char *, uint32, c
   pstrcpy(p,"B13BWz");
   p = skip_string(p,1);
   SSVAL(p,0,1);
-  SSVAL(p,2,0xFFFF);
+  /*
+   * Win2k needs a *smaller* buffer than 0xFFFF here -
+   * it returns "out of server memory" with 0xFFFF !!! JRA.
+   */
+  SSVAL(p,2,0xFFE0);
   p += 4;
 
   if (cli_api(cli, 
               param, PTR_DIFF(p,param), 1024,  /* Param, length, maxlen */
-              NULL, 0, 0xFFFF,            /* data, length, maxlen */
+              NULL, 0, 0xFFE0,            /* data, length, maxlen - Win2k needs a small buffer here too ! */
               &rparam, &rprcnt,                /* return params, length */
               &rdata, &rdrcnt))                /* return data, length */
     {
@@ -575,7 +579,7 @@ BOOL cli_RNetShareEnum(struct cli_state *cli, void (*fn)(const char *, uint32, c
 		      int type = SVAL(p,14);
 		      int comment_offset = IVAL(p,16) & 0xFFFF;
 		      char *cmnt = comment_offset?(rdata+comment_offset-converter):"";
-		      fn(sname, type, cmnt);
+		      fn(sname, type, cmnt, state);
 	      }
       } else {
 	      DEBUG(4,("NetShareEnum res=%d\n", res));
@@ -601,7 +605,7 @@ The callback function takes 3 arguments: the machine name, the server type and
 the comment.
 ****************************************************************************/
 BOOL cli_NetServerEnum(struct cli_state *cli, char *workgroup, uint32 stype,
-		       void (*fn)(const char *, uint32, const char *))
+		       void (*fn)(const char *, uint32, const char *, void *), void *state)
 {
 	char *rparam = NULL;
 	char *rdata = NULL;
@@ -652,7 +656,7 @@ BOOL cli_NetServerEnum(struct cli_state *cli, char *workgroup, uint32 stype,
 
 				stype = IVAL(p,18) & ~SV_TYPE_LOCAL_LIST_ONLY;
 
-				fn(sname, stype, cmnt);
+				fn(sname, stype, cmnt, state);
 			}
 		}
 	}
@@ -861,6 +865,7 @@ BOOL cli_send_tconX(struct cli_state *cli,
 
 	slprintf(fullshare, sizeof(fullshare)-1,
 		 "\\\\%s\\%s", cli->desthost, share);
+	unix_to_dos(fullshare, True);
 	strupper(fullshare);
 
 	set_message(cli->outbuf,4,
@@ -1989,7 +1994,7 @@ static int interpret_long_filename(int level,char *p,file_info *finfo)
   do a directory listing, calling fn on each file found
   ****************************************************************************/
 int cli_list(struct cli_state *cli,const char *Mask,uint16 attribute, 
-	     void (*fn)(file_info *, const char *))
+	     void (*fn)(file_info *, const char *, void *), void *state)
 {
 	int max_matches = 512;
 	/* NT uses 260, OS/2 uses 2. Both accept 1. */
@@ -2140,7 +2145,7 @@ int cli_list(struct cli_state *cli,const char *Mask,uint16 attribute,
 
 	for (p=dirlist,i=0;i<total_received;i++) {
 		p += interpret_long_filename(info_level,p,&finfo);
-		fn(&finfo, Mask);
+		fn(&finfo, Mask, state);
 	}
 
 	/* free up the dirlist buffer */
@@ -2777,7 +2782,7 @@ BOOL cli_establish_connection(struct cli_state *cli,
 	return True;
 }
 
-
+#if 0
 /****************************************************************************
   cancel a print job
   ****************************************************************************/
@@ -2815,7 +2820,6 @@ int cli_printjob_del(struct cli_state *cli, int job)
 	return ret;
 }
 
-
 /****************************************************************************
 call fn() on each entry in a print queue
 ****************************************************************************/
@@ -2886,6 +2890,7 @@ int cli_print_queue(struct cli_state *cli,
 
 	return i;
 }
+#endif
 
 /****************************************************************************
 check for existance of a dir
