@@ -11,8 +11,6 @@
                1997 Norbert Warmuth.
 	       2000 Pavel Machek
    
-   $Id: undelfs.c,v 1.15 2001/06/11 21:58:58 proskin Exp $
- 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public License
    as published by the Free Software Foundation; either version 2 of
@@ -39,7 +37,6 @@
 #include <errno.h>
 
 #include <stdio.h>
-#include <fcntl.h>
 #include <stdlib.h>
 /* asm/types.h defines its own umode_t :-( */
 #undef umode_t
@@ -51,10 +48,8 @@
 
 #include "vfs.h"
 
-void print_vfs_message(char *, ...);
-
 struct deleted_info {
-    ino_t   ino;
+    ext2_ino_t   ino;
     unsigned short mode;
     unsigned short uid;
     unsigned short gid;
@@ -65,7 +60,7 @@ struct deleted_info {
 };
 
 struct lsdel_struct {
-    ino_t                   inode;
+    ext2_ino_t                   inode;
     int                     num_blocks;
     int                     free_blocks;
     int                     bad_blocks;
@@ -173,7 +168,7 @@ static int
 undelfs_loaddel (void)
 {
     int retval, count;
-    ino_t ino;
+    ext2_ino_t ino;
     struct ext2_inode inode;
     ext2_inode_scan   scan;
     
@@ -294,68 +289,58 @@ undelfs_opendir (vfs *me, char *dirname)
     }
 
     if (ext2fs_open (ext2_fname, 0, 0, 0, unix_io_manager, &fs)){
-	message_2s (1, undelfserr, _(" Could not open file %s "), ext2_fname);
+	message_2s (1, undelfserr, _(" Cannot open file %s "), ext2_fname);
 	return 0;
     }
     print_vfs_message (_("undelfs: reading inode bitmap..."));
     if (ext2fs_read_inode_bitmap (fs)){
 	message_2s (1, undelfserr,
-		 _(" Could not load inode bitmap from: \n %s \n"), ext2_fname);
+		 _(" Cannot load inode bitmap from: \n %s \n"), ext2_fname);
 	goto quit_opendir;
     }
     print_vfs_message (_("undelfs: reading block bitmap..."));
     if (ext2fs_read_block_bitmap (fs)){
 	message_2s (1, undelfserr,
-		 _(" Could not load block bitmap from: \n %s \n"), ext2_fname);
+		 _(" Cannot load block bitmap from: \n %s \n"), ext2_fname);
 	goto quit_opendir;
     }
     /* Now load the deleted information */
     if (!undelfs_loaddel ())
 	goto quit_opendir;
-    print_vfs_message (_("undelfs: done."));
+    print_vfs_message (_("%s: done."), me->name);
     return fs;
 quit_opendir:
-    print_vfs_message (_("undelfs: failure"));
+    print_vfs_message (_("%s: failure"), me->name);
     ext2fs_close (fs);
     fs = NULL;
     return 0;
 }
 
-/* Explanation:
- * On some operating systems (Slowaris 2 for example)
- * the d_name member is just a char long (Nice trick that break everything,
- * so we need to set up some space for the filename.
- */
-static struct {
-    struct dirent dent;
-#ifdef NEED_EXTRA_DIRENT_BUFFER
-    char extra_buffer [MC_MAXPATHLEN];
-#endif
-} undelfs_readdir_data;
 
 static void *
-undelfs_readdir (void *vfs_info)
+undelfs_readdir(void *vfs_info)
 {
+    static union vfs_dirent undelfs_readdir_data;
     char *dirent_dest;
-    
-    if (vfs_info != fs){
-	message_1s (1, undelfserr, _(" vfs_info is not fs! "));
+
+    if (vfs_info != fs) {
+	message_1s(1, undelfserr, _(" vfs_info is not fs! "));
 	return NULL;
     }
     if (readdir_ptr == num_delarray)
 	return NULL;
-    dirent_dest = (char *) &(undelfs_readdir_data.dent.d_name [0]);
+    dirent_dest = undelfs_readdir_data.dent.d_name;
     if (readdir_ptr < 0)
-	g_snprintf(dirent_dest, MC_MAXPATHLEN, "%s", readdir_ptr == -2 ? "." : "..");
+	g_snprintf(dirent_dest, MC_MAXPATHLEN, "%s",
+		   readdir_ptr == -2 ? "." : "..");
     else
 	g_snprintf(dirent_dest, MC_MAXPATHLEN, "%ld:%d",
-		 (long)delarray [readdir_ptr].ino,
-		 delarray [readdir_ptr].num_blocks);
+		   (long) delarray[readdir_ptr].ino,
+		   delarray[readdir_ptr].num_blocks);
     readdir_ptr++;
-    
-#if 0
-    undelfs_readdir_data.dent.d_namlen = strlen (undelfs_readdir_data.dent.d_name);
-#endif
+
+    compute_namelen(&undelfs_readdir_data.dent);
+
     return &undelfs_readdir_data;
 }
 
@@ -372,7 +357,7 @@ typedef struct {
     int  pos;			/* file position */
     int  current;		/* used to determine current position in itereate */
     int  finished;
-    ino_t inode;
+    ext2_ino_t inode;
     int  bytes_read;
     long size;
     
@@ -386,7 +371,7 @@ static void *
 undelfs_open (vfs *me, char *fname, int flags, int mode)
 {
     char *file, *f;
-    ino_t  inode, i;
+    ext2_ino_t  inode, i;
     undelfs_file *p = NULL;
     
     /* Only allow reads on this file system */
@@ -530,7 +515,7 @@ undelfs_read (void *vfs_info, char *buffer, int count)
 static long
 undelfs_getindex (char *path)
 {
-    ino_t inode = atol (path);
+    ext2_ino_t inode = atol (path);
     int i;
 
     for (i = 0; i < num_delarray; i++){
@@ -623,7 +608,7 @@ undelfs_chdir(vfs *me, char *path)
     /* this could be fixed by making an ext2fs io manager to use */
     /* our vfs, but that is left as an excercise for the reader */
     if ((fd = open (file, O_RDONLY)) == -1){
-	message_2s (1, undelfserr, _(" Could not open file: %s "), file);
+	message_2s (1, undelfserr, _(" Cannot open file %s "), file);
 	g_free (f);
 	g_free (file);
 	return -1;
