@@ -1,15 +1,12 @@
 #ifndef DIRENTRY_H
 #define DIRENTRY_H
 
-/* $Id: xdirentry.h,v 1.15 2001/08/03 10:15:17 andrew Exp $ */
-
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <fcntl.h>
 #include <unistd.h>
 #include <signal.h>
 #include <errno.h>
@@ -40,7 +37,7 @@ typedef struct vfs_s_entry {
     struct vfs_s_inode *dir;	/* Directory we are in - needed for invalidating directory when file in it changes */
     char *name;			/* Name of this entry */
     struct vfs_s_inode *ino;	/* ... and its inode */
-    int magic;
+/*  int magic; */
 #define ENTRY_MAGIC 0x014512563
 } vfs_s_entry;
 
@@ -69,7 +66,7 @@ typedef struct vfs_s_inode {
 	    struct timeval timestamp;
 	} ftp;
     } u;
-    int magic;
+/*  int magic; */
 #define INODE_MAGIC 0x93451656
 } vfs_s_inode;
 
@@ -89,21 +86,20 @@ typedef struct vfs_s_super {
 	} tar;
 	struct {
 	    int sockr, sockw;
-	    char *home, *cwdir;
+	    char *cwdir;
 	    char *host, *user;
 	    char *password;
 	    int flags;
 	} fish;
 	struct {
 	    int sock;
-	    char *home, *cwdir;
+	    char *cwdir;
 	    char *host, *user;
 	    char *password;
 	    int port;
 
-	    char *proxy;
+	    char *proxy;		/* proxy server, NULL if no proxy */
 	    int failed_on_login;	/* used to pass the failure reason to upper levels */
-	    int use_proxy;		/* use a proxy server */
 	    int use_source_route;
 	    int use_passive_connection;
 	    int remote_is_amiga;       /* No leading slash allowed for AmiTCP (Amiga) */
@@ -113,6 +109,7 @@ typedef struct vfs_s_super {
 	    int strict; /* ftp server doesn't understand 
 					   "LIST -la <path>"; use "CWD <path>"/
 					   "LIST" instead */
+	    int control_connection_buzy;
 #define RFC_AUTODETECT 0
 #define RFC_DARING 1
 #define RFC_STRICT 2
@@ -125,7 +122,7 @@ typedef struct vfs_s_super {
 	    struct defer_inode *defered; /* List of inodes for which another entries may appear */
 	} cpio;
     } u;
-    int magic;
+/*  int magic; */
 #define SUPER_MAGIC 0x915ac312
 } vfs_s_super;
 
@@ -137,13 +134,13 @@ typedef struct vfs_s_fh {
     int linear;	 /* Is that file open with O_LINEAR? */
     union {
 	struct {
-	    int got, total;
+	    int got, total, append;
 	} fish;
 	struct {
-	    int sock;
+	    int sock, append;
 	} ftp;
     } u;
-    int magic;
+/*  int magic; */
 #define FH_MAGIC 0x91324682
 } vfs_s_fh;
 
@@ -168,7 +165,7 @@ struct vfs_s_data {
     vfs_s_entry* (*find_entry) (vfs *me, vfs_s_inode *root, char *path, int follow, int flags);
     int (*dir_load) (vfs *me, vfs_s_inode *ino, char *path);
     int (*dir_uptodate) (vfs *me, vfs_s_inode *ino);
-    int (*file_store) (vfs *me, vfs_s_super *super, char *path, char *localname);
+    int (*file_store) (vfs *me, vfs_s_fh *fh, char *path, char *localname);
 
     int (*linear_start) (vfs *me, vfs_s_fh *fh, int from);
     int (*linear_read) (vfs *me, vfs_s_fh *fh, void *buf, int len);
@@ -254,11 +251,8 @@ int vfs_s_get_line_interruptible (vfs *me, char *buffer, int size, int fd);
 int vfs_s_retrieve_file (vfs *me, struct vfs_s_inode *ino);
 
 #if 0
-/* If non-null, FREE */
-#define ifree(ptr) do { if (ptr) g_free(ptr); } while (0)
 #define ERRNOR(a, b) do { me->verrno = a; return b; } while (0)
 #else
-#define ifree(ptr) { if (ptr) g_free(ptr); }
 #define ERRNOR(a, b) { me->verrno = a; return b; }
 #endif
 
